<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'De Plugin activ&eacute;ieren',
'affichage' => 'Uweisen',
'aide_non_disponible' => 'D&euml;sen Deel vun der H&euml;llef g&euml;tt et nach n&euml;t an d&auml;r Sprooch.',
'auteur' => 'Auteur:',
'avis_acces_interdit' => 'Zougang gespaart.',
'avis_article_modifie' => 'Opgepasst, den @nom_auteur_modif@ huet un d&euml;sem Artikel virun @date_diff@ Minuten geschafft',
'avis_aucun_resultat' => 'Kee Resultat.',
'avis_chemin_invalide_1' => 'De Wee deen dir gewielt hutt',
'avis_chemin_invalide_2' => 'schengt n&euml;t g&euml;lteg ze sinn. Gidd op d&eacute;i l&auml;scht S&auml;it zer&euml;ck a kontroll&eacute;iert d\'Informatiounen.',
'avis_connexion_echec_1' => 'D\'Verbannen mat der Datebank huet n&euml;t fonktionn&eacute;iert.',
'avis_connexion_echec_2' => 'Gidd op d&eacute;i l&auml;scht S&auml;it zer&euml;ck a kontroll&eacute;iert d\'Informatiounen.',
'avis_connexion_echec_3' => '<b>N.B.</b> Op ville Server\'en muss der d\'Aktivatioun vun engem Zougang un d\'Datebank <b>ufro&euml;n</b>, ier der se k&euml;nnt benotzen. Wann der keng Verbindung kritt, kontroll&eacute;iert op dat gemaach ass.',
'avis_connexion_ldap_echec_1' => 'D\'Verbindung mam LDAP-Server huet n&euml;t fonktionn&eacute;iert.',
'avis_connexion_ldap_echec_2' => 'Gidd op d&eacute;i l&auml;scht S&auml;it zer&eacute;ck a kontroll&eacute;iert d\'Informatiounen.',
'avis_connexion_ldap_echec_3' => 'Alternativ benotzt keng LDAP-&Euml;nnerstetzung fir d\'Benotzer ze import&eacute;ieren.',
'avis_conseil_selection_mot_cle' => '<b>Wichtege Grupp:</b> &euml;t ass wiirklech ugeroden e Schl&euml;sselwuert aus d&euml;sem Grupp ze wielen.',
'avis_deplacement_rubrique' => 'Opgepasst! D&euml;s Rubrik huet @contient_breves@ br&egrave;ve@scb@: wann der se r&eacute;ckelt, klickt d&euml;st Konfirmatiouns-Feld un.',
'avis_destinataire_obligatoire' => 'Dir musst d&euml;n Empf&auml;nger uginn ier der d&euml;sen Message fortsch&eacute;ckt.',
'avis_doublon_mot_cle' => 'Un mot existe deja avec ce titre. &Ecirc;tes vous s&ucirc;r de vouloir cr&eacute;er le m&ecirc;me ?', # NEW
'avis_erreur_connexion_mysql' => 'Fehler bei der SQL-Verbindung',
'avis_erreur_version_archive' => 'Opgepasst! De Fichier @archive@ korrespond&eacute;iert zu enger anerer SPIP-Versioun w&eacute;i d&eacute;i install&eacute;iert.
Dir kommt an grouss Schwieregkeeten:
Risiko dass &auml;r Datebank zerst&eacute;iert g&euml;t, generellen Disfonktionnement vum Site, asw. Best&auml;tegt d&euml;sen Import n&euml;t.<p>Fir m&eacute;i Informatiounen kuckt an <a href="@spipnet@">
der Dokumentatioun vu SPIP</a>.</p>', # MODIF
'avis_espace_interdit' => '<b>Gespaarten Deel</b><p>SPIP ass schon install&eacute;iert.</p>',
'avis_lecture_noms_bases_1' => 'Den Installatiouns-Programm konnt d\'Nimm vun den install&eacute;iertent Datebanken n&euml;t liesen.',
'avis_lecture_noms_bases_2' => 'Etweder steet keng Datebank zur Verf&uuml;gung, oder d\'Fonktioun fir d\'Datebanken opzel&euml;schten ass aus S&euml;cherheetsgr&euml;nn ausgeschalt ginn (dat ass esou bei villen Provider\'en).',
'avis_lecture_noms_bases_3' => 'Am zweeten Fall ass et m&eacute;iglech dass eng Datebank mam selwechten Numm w&eacute;i &auml;ren Login ka benotzt ginn:',
'avis_non_acces_message' => 'Dir hutt keen Zougang zu d&euml;sem Message.',
'avis_non_acces_page' => 'Dir hutt keen Zougang zu d&euml;ser S&auml;it.',
'avis_operation_echec' => 'D&eacute;i Operatioun huet n&euml;t fonktionn&eacute;iert.',
'avis_operation_impossible' => 'Operatioun onm&eacute;iglech',
'avis_probleme_archive' => 'Problem beim Liesen vum Fichier @archive@',
'avis_site_introuvable' => 'De Site ass n&euml;t ze fannen',
'avis_site_syndique_probleme' => 'Opgepasst: d\'Syndicatioun vun d&euml;sem Site huet n&euml;t fonktionn&eacute;iert; de System ass elo z&auml;itweis &euml;nnerbrach. Kontroll&eacute;iert d\'Adress vum Syndicatiouns-Fichier vun d&euml;sem Site (<b>@url_syndic@</b>) a prob&eacute;iert nach eng K&eacute;ier d\'Informatiounen ze kr&eacute;ien.',
'avis_sites_probleme_syndication' => 'D&euml;s Siten hun e Syndicatiouns-Problem',
'avis_sites_syndiques_probleme' => 'D&euml;s syndik&eacute;iert Siten hun e Problem',
'avis_suppression_base' => 'OPGEPASST, d\'L&auml;schen vun den Daten ka n&euml;t reckg&auml;ngeg gemach ginn',
'avis_version_mysql' => '&Auml;r SQL-Versioun (@version_mysql@) erlaabt d\'automatesch Reparatur vun den Datebank-Tafelen n&euml;t.',

// B
'bouton_acces_ldap' => 'LDAP-Zougang derb&auml;i setzen',
'bouton_ajouter' => 'Derb&auml;i setzen',
'bouton_ajouter_participant' => 'MATAARBECHTER DERB&Auml;I SETZEN:',
'bouton_annonce' => 'ANNONCE',
'bouton_annuler' => 'Ofbriechen',
'bouton_checkbox_envoi_message' => '&euml;t kann e Message gesch&eacute;ckt ginn',
'bouton_checkbox_indiquer_site' => 'dir musst en Internet-Site uginn',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'd\'Administrateuren vum Site',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'd\'Redakteren',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'd\'Visiteuren vum Site wann se e Message an de Forum sch&eacute;cken.',
'bouton_checkbox_signature_unique_email' => 'eng eenzeg &Euml;nnerschr&euml;ft pro Email-Adress',
'bouton_checkbox_signature_unique_site' => 'Eng eenzeg &Euml;nnerschr&euml;ft pro Internet-Site',
'bouton_demande_publication' => 'D\'Publikatioun vum Artikel ufro&euml;n',
'bouton_desactive_tout' => 'Alles d&eacute;sactiv&eacute;ieren',
'bouton_desinstaller' => 'De-install&eacute;ieren',
'bouton_effacer_index' => 'Den Index l&auml;schen',
'bouton_effacer_statistiques' => 'Statistik l&auml;schen',
'bouton_effacer_tout' => 'ALLES l&auml;schen',
'bouton_envoi_message_02' => 'MESSAGE SCH&Eacute;CKEN',
'bouton_envoyer_message' => 'Definitiven Message: sch&eacute;cken',
'bouton_forum_petition' => 'FORUM &amp; PETITIOUN',
'bouton_modifier' => '&Auml;nneren',
'bouton_pense_bete' => 'PERS&Eacute;INLECH NOTIZ',
'bouton_radio_activer_messagerie' => 'D&eacute;i intern Messagerie aschalten',
'bouton_radio_activer_messagerie_interne' => 'D&eacute;i intern Messagerie aschalten',
'bouton_radio_activer_petition' => 'D\'Petitioun aschalten',
'bouton_radio_afficher' => 'Weisen',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Op d\'L&euml;scht vun den ugemelten Redakteren kommen',
'bouton_radio_articles_futurs' => 'n&euml;mmen fir nei Artikelen (keng Aktioun op d\'Datebank).',
'bouton_radio_articles_tous' => 'fir all nei Artikelen ouni Ausnahm.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'fir all Artikelen, ausser d&eacute;i wou de Forum ausgeschalt ass.',
'bouton_radio_desactiver_messagerie' => 'D\'Messagerie ausschalten',
'bouton_radio_enregistrement_obligatoire' => 'Obligatoresch Aschreiwung (d\'Benotzer mussen sech abonn&eacute;ieren andeem si hier Email-Adress uginn ier se hier Beitr&auml;g k&euml;nne sch&eacute;cken).',
'bouton_radio_envoi_annonces_adresse' => 'D\'Annoncen sch&eacute;cken op d\'Adress:',
'bouton_radio_envoi_liste_nouveautes' => 'D\'L&euml;scht mat den Neiegkeeten sch&eacute;cken',
'bouton_radio_moderation_priori' => 'Moderatioun &agrave; priori (d\'Beitr&auml;g ginn er&eacute;ischt publiz&eacute;iert nodeem se vun engem Administrateur valid&eacute;iert goufen).',
'bouton_radio_modere_abonnement' => 'op Abonnement',
'bouton_radio_modere_posteriori' => 'mod&eacute;r&eacute;iert "&agrave; posteriori"',
'bouton_radio_modere_priori' => 'mod&eacute;r&eacute;iert "&agrave; priori"',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'N&euml;t op d\'L&euml;scht vun de Redakteren kommen',
'bouton_radio_non_envoi_annonces_editoriales' => 'Keng editorial Neiegkeeten sch&eacute;cken',
'bouton_radio_non_syndication' => 'Keng Syndicatioun',
'bouton_radio_pas_petition' => 'Keng Petitioun',
'bouton_radio_petition_activee' => 'Petitioun ageschalt',
'bouton_radio_publication_immediate' => 'Direkt Publikatioun vun de Messagen (d\'Beitr&auml;g ginn direkt nom Sch&eacute;cken sichtbar, d\'Administrateuren k&euml;nnen se duerno l&auml;schen).',
'bouton_radio_sauvegarde_compressee' => 'Backup ass komprim&eacute;iert &euml;nner @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'Backup ass n&euml;t komprim&eacute;iert &euml;nner @fichier@',
'bouton_radio_supprimer_petition' => 'D\'Petitioun l&auml;schen',
'bouton_radio_syndication' => 'Syndicatioun:',
'bouton_redirection' => '&Euml;MLEEDUNG',
'bouton_relancer_installation' => 'D\'Installatioun nei uf&auml;nken',
'bouton_restaurer_base' => 'Datebank restaur&eacute;ieren',
'bouton_suivant' => 'Weider',
'bouton_tenter_recuperation' => 'Eng Reparatur prob&eacute;ieren',
'bouton_test_proxy' => 'E Proxy prob&eacute;ieren',
'bouton_vider_cache' => 'De Cache l&auml;schen',
'bouton_voir_message' => 'De Message weisen ier e valid&eacute;iert g&euml;tt',

// C
'cache_mode_compresse' => 'D\'Fichier\'en am Cache si komprim&eacute;iert gesp&auml;ichert.',
'cache_mode_non_compresse' => 'D\'Fichier\'en am Cache si n&euml;t komprim&eacute;iert gesp&auml;ichert.',
'cache_modifiable_webmestre' => 'D&euml;sen Parameter kann vum Webmaster vum Site ge&auml;nnert ginn.',
'calendrier_synchro' => 'Wann dir en <b>iCal</b>-kompatiblen Agenda benotzt, da k&euml;nnt der d\'Informatiounen mat d&euml;sem Site synchronis&eacute;ieren.',
'config_activer_champs' => 'Folgend Felder aktiv&eacute;ieren',
'config_choix_base_sup' => 'eng Datebank op d&euml;sem Server uginn',
'config_erreur_base_sup' => 'SPIP huet keen Zougr&euml;ff op d\'L&euml;scht vun den Datebanken',
'config_info_base_sup' => 'Wann dir via SPIP aner Datebanken w&euml;llt benotzen, mat s&euml;ngem SQL-Server oder engem aneren, dann deklar&eacute;iert s&euml; mat d&euml;sem Formulaire. Wann dir Felder eidel losst da gin d\'Daten vun der Haaptdatebank benotzt.',
'config_info_base_sup_disponibles' => 'Zous&auml;tzlech Datebanken d&eacute;i ufrobar sin:',
'config_info_enregistree' => 'Enrollet eo bet mat ar c\'hefluniadur nevez',
'config_info_logos' => 'All Element vum Site kann e Logo an e MouseOver-Logo hun.',
'config_info_logos_utiliser' => 'Logo\'en benotzen',
'config_info_logos_utiliser_non' => 'K&eacute;ng Logo\'en benotzen',
'config_info_logos_utiliser_survol' => 'MouseOver-Logo\'en benotzen',
'config_info_logos_utiliser_survol_non' => 'K&eacute;ng MouseOver-Logo\'en benotzen',
'config_info_redirection' => 'Wann d&euml;s Optioun un ass k&euml;nnt dur virtuell Artikelen maachen (Referenzen op Artikelen vun aner Siten oder vun ausserhalb vu SPIP).',
'config_redirection' => 'Virtuell Artikelen',
'config_titre_base_sup' => 'Deklaratioun vun enger zous&auml;tzlecher Datebank',
'config_titre_base_sup_choix' => 'Wielt eng zous&auml;tzlech Datebank aus',
'connexion_ldap' => 'Verbindung:',
'copier_en_local' => 'Lokal kop&eacute;ieren',

// D
'date_mot_heures' => 'h',
'diff_para_ajoute' => 'Kapitel derb&auml;i setzen',
'diff_para_deplace' => 'Kapitel ger&eacute;ckelt',
'diff_para_supprime' => 'Kapitel gel&auml;scht',
'diff_texte_ajoute' => 'Text derb&auml;i setzen',
'diff_texte_deplace' => 'Text ger&eacute;ckelt',
'diff_texte_supprime' => 'Text gel&auml;scht',
'double_clic_inserer_doc' => 'Duebel-Klick fir d&euml;s Ofkirzung an den Text ze iwerhuelen',

// E
'email' => 'Email',
'email_2' => 'Email:',
'en_savoir_plus' => 'En savoir plus', # NEW
'entree_adresse_annuaire' => 'Adress vun der Sammlung',
'entree_adresse_email' => '&Auml;r Email-Adress',
'entree_adresse_fichier_syndication' => 'Adress vum Fichier fir d\'Syndicatioun:',
'entree_adresse_site' => '<b>Adress vum Site</b> [Obligatoresch]',
'entree_base_donnee_1' => 'Adress vun der Datebank',
'entree_base_donnee_2' => '(D&euml;s Adress ass oft selw&euml;cht w&eacute;i d&eacute;i vun &auml;rem Site, heiansdo ass &euml;t "localhost", heiansdo g&euml;t se eidel gelooss.)',
'entree_biographie' => 'Kuerz Biographie an e puer Wierder.',
'entree_breve_publiee' => 'Soll d&euml;s Kuerzmeldung publiz&eacute;iert ginn?',
'entree_chemin_acces' => 'De Wee <b>aginn</b>:',
'entree_cle_pgp' => '&Auml;re PGP-Schl&euml;ssel',
'entree_contenu_rubrique' => '(Inhalt vun der Rubrik an e puer Wierder.)',
'entree_description_site' => 'Beschreiwung vum Site',
'entree_identifiants_connexion' => '&Auml;r Zougangs-Informatiounen...',
'entree_informations_connexion_ldap' => 'Gidd an d&euml;sen Formulaire d\'Informatiounen vun &auml;rer LDAP-Verbindung an.
D&euml;s Informatiounen kritt dir vum Administrateur vum System oder vum Netzwierk.',
'entree_infos_perso' => 'Wie sidd Dir?',
'entree_interieur_rubrique' => 'An der Rubrik:',
'entree_liens_sites' => '<b>Link</b> (Referenz, interessante Site...)',
'entree_login' => '&Auml;re Login',
'entree_login_connexion_1' => 'De Login fir d\'Verbindung',
'entree_login_connexion_2' => '(Ass heiansdo selw&euml;cht w&eacute;i &auml;ren FTP-Login, heiansdo g&euml;t en eidel gelooss)',
'entree_login_ldap' => 'Initialen LDAP-Login',
'entree_mot_passe' => '&Auml;rt Passwuert',
'entree_mot_passe_1' => 'D\'Passwuert fir d\'Verbindung',
'entree_mot_passe_2' => '(Ass heiansdo selw&euml;cht w&eacute;i &auml;rt FTP-Passwuert; g&euml;t heianso eidel gelooss)',
'entree_nom_fichier' => 'Gidd de Numm vum Fichier @texte_compresse@ an:',
'entree_nom_pseudo' => '&Auml;re Numm oder &auml;re Pseudo',
'entree_nom_pseudo_1' => '(&Auml;re Numm oder &auml;re Pseudo)',
'entree_nom_site' => 'De Numm vun &auml;rem Site',
'entree_nouveau_passe' => 'Neit Passwuert',
'entree_passe_ldap' => 'Passwuert',
'entree_port_annuaire' => 'D\'Port-Nummer vun der L&euml;scht',
'entree_signature' => '&Euml;nnerschr&euml;ft',
'entree_texte_breve' => 'Text vun der Kuerzmeldung',
'entree_titre_obligatoire' => '<b>Titel</b> [Obligatoresch]<br />',
'entree_url' => 'D\'Adress (URL) vun &auml;rem Site',
'erreur_plugin_desinstalation_echouee' => 'La d&eacute;sinstallation du plugin a echou&eacute;. Vous pouvez n&eacute;anmoins le desactiver.', # NEW
'erreur_plugin_fichier_absent' => 'Fichier fehlt',
'erreur_plugin_fichier_def_absent' => 'Definitiouns-Fichier fehlt',
'erreur_plugin_nom_fonction_interdit' => 'Fonktiouns-Numm verbueden',
'erreur_plugin_nom_manquant' => 'Num vum Plugin fehlt',
'erreur_plugin_prefix_manquant' => 'Namespace vum Plugin n&euml;t defin&eacute;iert',
'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; fehlt am Definitiouns-Fichier',
'erreur_plugin_version_manquant' => 'Versioun vum Plugin fehlt',

// F
'forum_info_original' => 'Original',

// H
'htaccess_a_simuler' => 'Avertissement: la configuration de votre serveur HTTP ne tient pas compte des fichiers @htaccess@. Pour pouvoir assurer une bonne s&eacute;curit&eacute;, il faut que vous modifiez cette configuration sur ce point, ou bien que les constantes @constantes@ (d&eacute;finissables dans le fichier mes_options.php) aient comme valeur des r&eacute;pertoires en dehors de @document_root@.', # NEW
'htaccess_inoperant' => 'htaccess inop&eacute;rant', # NEW

// I
'ical_info1' => 'D&euml;s S&auml;it bitt verschidde M&eacute;igl&euml;chkeeten fir mam Liewen vun d&euml;sem Site a Kontakt ze bleiwen.',
'ical_info2' => 'Fir m&eacute;i Informatiounen iwer d&euml;s Technik, kuckt an <a href="@spipnet@">der SPIP-Dokumentatioun</a>.',
'ical_info_calendrier' => '&Euml;t ginn zwee Kalenneren. Deen &eacute;ischten ass e Plang vum Site mat all den Annoncen vun den publiz&eacute;ierten Artikelen. Deen zweeten huet all editorial Annoncen an &auml;r l&auml;schten privat Messagen: hien ass mat engem pers&eacute;inlechen Schl&euml;ssel fir Iech reserv&eacute;iert, deen dir zu all Moment &auml;nnere k&euml;nnt wann d&euml;r &auml;rt Passwuert &auml;nnert.',
'ical_lien_rss_breves' => 'Syndicatioun vun de Kurzmeldungen vum Site',
'ical_methode_http' => 'Downlueden',
'ical_methode_webcal' => 'Synchronisatioun (webcal://)',
'ical_texte_js' => 'Eng Javascript-Zeil erlaabt ganz einfach op egal wat fir engem vun &auml;re Siten d&eacute;i l&auml;schten Artikelen vun d&euml;sem Site ze weisen.',
'ical_texte_prive' => 'D&euml;se Kalenner, den n&euml;mmen just Iech geh&eacute;iert, inform&eacute;iert Iech iwwert d&eacute;i editorial Aktivit&eacute;iten vun d&euml;sem Site (Aufgaben a pers&eacute;inlech Rendez-vous\'en, propos&eacute;iert Artikelen a Kuerzmeldungen...).',
'ical_texte_public' => 'D&euml;se Kalenner erlaabt Iech d&eacute;i &ouml;ffentl&euml;ch Aktivit&eacute;it vun d&euml;sem Site ze verfolgen (puliz&eacute;iert Artikelen a Kuerzmeldungen).',
'ical_texte_rss' => 'Dir kennt nei Siten an egal wat fir engem Programm mam Format XML/RSS (Rich Site Summary) syndiqu&eacute;ieren. SPIP kann och d\'Neiegkeetn vun anere Siten mat deem Format liesen (syndik&eacute;iert Siten).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Mailing-L&euml;scht',
'ical_titre_rss' => 'Syndicatiouns-Fichier\'en',
'icone_activer_cookie' => 'De Korrespondenz-Cookie activ&eacute;ieren',
'icone_admin_plugin' => 'Plugin\'en verwalten',
'icone_afficher_auteurs' => 'Auteuren weisen',
'icone_afficher_visiteurs' => 'Visiteuren weisen',
'icone_arret_discussion' => 'N&euml;t m&eacute;i un d&euml;ser Diskussioun deelhuelen',
'icone_calendrier' => 'Kalenner',
'icone_creation_groupe_mots' => 'E Schl&euml;sselwierder-Grupp maachen',
'icone_creation_mots_cles' => 'E Schl&euml;sselwuert maachen',
'icone_creer_auteur' => 'E neien Auteur derb&auml;i setzen an un d&euml;sen Artikel bannen',
'icone_creer_mot_cle' => 'E neit Schl&euml;sselwuert derb&auml;i setzen an un d&euml;sen Artikel bannen',
'icone_creer_mot_cle_breve' => 'E neit Schl&euml;sselwuert maachen an et un d&euml;s Kurzmeldung bannen',
'icone_creer_mot_cle_rubrique' => 'E neit Schl&euml;sselwuert maachen an et un d&euml;s Rubrik bannen',
'icone_creer_mot_cle_site' => 'E neit Schl&euml;sselwuert maachen an et un d&euml;se Site bannen',
'icone_creer_rubrique_2' => 'Nei Rubrik derb&auml;i setzen',
'icone_ecrire_nouvel_article' => 'Kuerzmeldungen aus d&euml;ser Rubrik',
'icone_envoyer_message' => 'D&euml;se Message sch&eacute;cken',
'icone_evolution_visites' => 'Evolutioun vun den Visiten<br />@visites@ Visiten',
'icone_modif_groupe_mots' => 'D&euml;se Schl&euml;sselwierder-Grupp &auml;nneren',
'icone_modifier_article' => 'D&euml;sen Artikel &auml;nneren',
'icone_modifier_breve' => 'D&euml;s Kuerzmeldung &auml;nneren',
'icone_modifier_message' => 'D&euml;se Message &auml;nneren',
'icone_modifier_mot' => 'D&euml;st Schl&euml;sselwuert &auml;nneren',
'icone_modifier_rubrique' => 'D&euml;s Rubrik &auml;nneren',
'icone_modifier_site' => 'D&euml;se Site &auml;nneren',
'icone_poster_message' => 'Message sch&eacute;cken',
'icone_publier_breve' => 'D&euml;s Kuerzmeldung publiz&eacute;ieren',
'icone_referencer_nouveau_site' => 'Neie Site uginn',
'icone_refuser_breve' => 'D&euml;s Kuerzmeldung refus&eacute;ieren',
'icone_relancer_signataire' => 'Beim &Euml;nnerschreiwer nofro&euml;n',
'icone_retour' => 'Zer&euml;ck',
'icone_retour_article' => 'Zer&euml;ck bei den Artikel',
'icone_suivi_forum' => 'Den &ouml;ffentlechen Forum verfolgen: @nb_forums@&nbsp;Beitr&auml;g',
'icone_supprimer_cookie' => 'Korrespondenz-Cookie l&auml;schen',
'icone_supprimer_groupe_mots' => 'D&euml;se Grupp l&auml;schen',
'icone_supprimer_rubrique' => 'D&euml;s Rubrik l&auml;schen',
'icone_supprimer_signature' => 'D&euml;s &Euml;nnerschr&euml;ft l&auml;schen',
'icone_valider_signature' => 'D&euml;s &Euml;nnerschr&euml;ft valid&eacute;ieren',
'icone_voir_sites_references' => 'Referenz&eacute;iert Siten weisen',
'icone_voir_tous_mots_cles' => 'All d\'Schl&euml;sselwierder weisen',
'image_administrer_rubrique' => 'Dir k&euml;nnt d&euml;s Rubrik administr&eacute;ieren',
'info_1_article' => '1 Artikel',
'info_1_breve' => '1 Kuerzmeldung',
'info_1_site' => '1 Site',
'info_activer_cookie' => 'Dir k&euml;nnt e <b>Korrespondenz-Cookie</b> aktiv&eacute;ieren, dien Iech erlaabt einfach vum &ouml;ffentl&euml;chen op de privaten Site ze wiesselen.',
'info_activer_forum_public' => '<i>Fir d&eacute;i &ouml;ffentl&euml;ch Forum\'en anzeschalten, wielt d\'Default-Moderatiouns-Method:</i>',
'info_admin_gere_rubriques' => 'D&euml;sen Administrateur k&euml;nmert s&euml;ch &euml;m folgend Rubriken:',
'info_admin_gere_toutes_rubriques' => 'D&euml;sen Administrateur k&euml;mmert s&euml;ch &euml;m <b>all Rubriken</b>.',
'info_admin_statuer_webmestre' => 'Donner &agrave; cet administrateur les droits de webmestre', # NEW
'info_admin_webmestre' => 'Cet administrateur est <b>webmestre</b>', # NEW
'info_administrateur' => 'Administrateur',
'info_administrateur_1' => 'Administrateur',
'info_administrateur_2' => 'vum Site (<i>oppassen beim benotzen)',
'info_administrateur_site_01' => 'Wann dir Administrateur vum Site sidd, ',
'info_administrateur_site_02' => 'klickt op d&euml;se Link',
'info_administrateurs' => 'Administrateuren',
'info_administrer_rubrique' => 'Dir k&euml;nnt d&euml;s Rubrik administr&eacute;ieren',
'info_adresse' => 'op der Adress:',
'info_adresse_email' => 'EMAIL-ADRESS:',
'info_adresse_url' => 'Adress (URL) vum &ouml;ffentl&euml;che Site',
'info_afficher_visites' => 'D\'Visiten weisen fir:',
'info_affichier_visites_articles_plus_visites' => 'D\'Visiten fir <b>d&eacute;i am meeschten gefroten Artikel z&euml;nter dem Ufank</b> weisen:',
'info_aide_en_ligne' => 'Online-H&euml;llef vu SPIP',
'info_ajout_image' => 'Wann dir engem Artikel Biller als Dokumenter derb&auml;i setzt, kann SPIP Iech automat&euml;sch Vignetten (Miniaturen) maachen. Dat erlaabt Iech z.B. automatesch eng Galerie ze maachen.',
'info_ajout_participant' => 'De folgenden gouf derb&auml;i gesat:',
'info_ajouter_rubrique' => 'Eng aner Rubrik fir ze administr&eacute;ieren derb&auml;i setzen:',
'info_annonce_nouveautes' => 'D\'Neiegkeeten annonc&eacute;ieren',
'info_anterieur' => 'viirdrun',
'info_appliquer_choix_moderation' => 'D&euml;s Moderatiouns-Method iwwerhuelen:',
'info_article' => 'Artikel',
'info_article_2' => 'Artikelen',
'info_article_a_paraitre' => 'D&eacute;i post-dat&eacute;iert Artikelen',
'info_articles_02' => 'Artikelen',
'info_articles_2' => 'Artikelen',
'info_articles_auteur' => 'Artikelen vun d&euml;sem Auteur',
'info_articles_lies_mot' => 'Artikelen d&eacute;i un d&euml;st Schl&euml;sselwuert gebonnen sinn',
'info_articles_trouves' => 'Artikelen fonnt',
'info_articles_trouves_dans_texte' => 'Artikelen fonnt (am Text)',
'info_attente_validation' => '&Auml;r Artikelen d&eacute;i op d\'Validatioun waarden',
'info_aujourdhui' => 'Haut:',
'info_auteur_message' => 'AUTEUR VUM MESSAGE:',
'info_auteurs' => 'D\'Auteuren',
'info_auteurs_par_tri' => 'Auteuren@partri@',
'info_auteurs_trouves' => 'Auteuren fonnt',
'info_authentification_externe' => 'Extern Umeldung',
'info_avertissement' => 'Warnung',
'info_barre_outils' => 'mat senger Toolbar?',
'info_base_installee' => 'D\'Struktur vun &auml;rer Datebank ass install&eacute;iert.',
'info_base_restauration' => 'D\'Datebank g&euml;t grad restaur&eacute;iert.',
'info_bloquer' => 'block&eacute;ieren',
'info_breves' => 'Benotzt &auml;re Site de Kuerzmeldungs-System?',
'info_breves_03' => 'Kuerzmeldungen',
'info_breves_liees_mot' => 'Kuerzmeldungen d&eacute;i un d&euml;st Schl&euml;sselwuert gebonnen sinn',
'info_breves_touvees' => 'Kuerzmeldungen fonnt',
'info_breves_touvees_dans_texte' => 'Kuerzmeldungen fonnt (am Text)',
'info_changer_nom_groupe' => 'Numm vun d&euml;sem Grupp &auml;nneren:',
'info_chapeau' => 'Chapeau',
'info_chapeau_2' => 'Chapeau:',
'info_chemin_acces_1' => 'Optiounen: <b>Wee an der L&euml;scht</b>',
'info_chemin_acces_2' => 'Dir musst de Wee op d\'Informatiounen an der L&euml;scht ugin. D&euml;s Informatioun ass n&eacute;ideg fir de Profil vun de Benotzer aus der L&euml;scht ze liesen.',
'info_chemin_acces_annuaire' => 'Optiounen: <b>Wee an der L&euml;scht</b>',
'info_choix_base' => 'Dr&euml;tte Schr&euml;tt:',
'info_classement_1' => '. an @liste@',
'info_classement_2' => '. an @liste@',
'info_code_acces' => 'Vergiesst &auml;r Login-Informatiounen n&euml;t!',
'info_comment_lire_tableau' => 'W&eacute;i een d&euml;s Tabell liesen soll',
'info_compresseur_gzip' => '<b>N.B.:</b> Kontroll&eacute;iert op &auml;ren Hebergeur PHP-Skripter komprim&eacute;iert; dir k&euml;nnt dofir d&euml;sen Service benotzen: @testgzip@',
'info_compresseur_texte' => 'Wann &auml;re Server d\'HTML-S&auml;iten n&euml;t automat&euml;sch komprim&eacute;iert, k&euml;nnt dir prob&eacute;ieren eng Kompressioun ze forc&eacute;ieren. <b>Opgepasst</b>: dat kann verschidde Serveren m&eacute;i lues maachen.',
'info_compresseur_titre' => 'Optimisatioun a Compressioun',
'info_config_forums_prive' => 'Am privaten Deel k&euml;nnt dir e puer Forumen aktiv&eacute;ieren:',
'info_config_forums_prive_admin' => 'E reserv&eacute;ierte Forum fir d\'Administrateuren vum Site:',
'info_config_forums_prive_global' => 'E globale Forum fir all Redakteren:',
'info_config_forums_prive_objets' => 'E Forum &euml;nnert all Artikel, Kurzmeldung, referenz&eacute;ierte Site, asw.:',
'info_config_suivi' => 'Wann d&euml;s Adress eng Mailing-L&euml;scht ass, da k&euml;nnt dier hei d\'Adress uginn wou d\'Matarbechter vun d&euml;sem Site sech aschreiwen k&euml;nnen. D&euml;s Adress kann eng URL sinn (z.B. d\'Internets&auml;it wou een s&euml;ch aschreiwen kann), oder eng Email-Adress mat engem extra Sujet (z.B.: <tt>@adresse_suivi@?subject=subscribe</tt>):',
'info_config_suivi_explication' => 'Dir k&euml;nnt Iech un d\'Mailing-L&euml;scht vun d&euml;sem Site abonn&eacute;ieren. Dir kritt dann per Email d\'Annoncen vun den Artikelen a Kuerzmeldungen d&eacute;i fir d\'Publikatioun propos&eacute;iert goufen.',
'info_confirmer_passe' => 'Konfirm&eacute;iert dat neit Passwuert:',
'info_conflit_edition_avis_non_sauvegarde' => 'Opgepasst, folgend Felder sinn ge&auml;nnert gin. &Auml;r &Auml;nnerunge sinn also n&euml;t gesp&auml;ichert gin.',
'info_conflit_edition_differences' => '&Euml;nnerscheeder:',
'info_conflit_edition_version_enregistree' => 'D&eacute;i gesp&auml;ichert Versioun:',
'info_conflit_edition_votre_version' => '&Auml;r Versioun:',
'info_connexion_base' => 'Versichen mat der Datebank ze verbannen',
'info_connexion_base_donnee' => 'Verbannen mat &auml;rer Datebank',
'info_connexion_ldap_ok' => 'D\'LDAP-Verbindung huet geklappt.</b><p>Weider bei de n&auml;chsten Schr&euml;tt.</p>', # MODIF
'info_connexion_mysql' => '&Auml;r SQL-Verbindung',
'info_connexion_ok' => 'D\'Verbindung huet geklappt.',
'info_contact' => 'Kontakt',
'info_contenu_articles' => 'Inhalt vun den Artikelen',
'info_creation_mots_cles' => 'Setzt hei d\'Schl&euml;sselwierder vum Site derb&auml;i a konfigur&eacute;iert se',
'info_creation_paragraphe' => '(Fir e neien Abschnitt, loosst einfach eng eidel Zeil.)',
'info_creation_rubrique' => 'Ier d&euml;r k&euml;nnt en Artikel schreiwen<br />musst d&euml;r op manst eng Rubrik derb&auml;i setzen.<br />',
'info_creation_tables' => 'Tabellen an d\'Datebank schreiwen',
'info_creer_base' => 'Eng nei Datebank <b>uleen</b>:',
'info_dans_groupe' => 'Am Grupp:',
'info_dans_rubrique' => 'An der Rubrik:',
'info_date_publication_anterieure' => '&Eacute;ischten Redaktiounsdatum:',
'info_date_referencement' => 'D&Euml;SE SITE GOUF REFERENZ&Eacute;IERT:',
'info_delet_mots_cles' => 'Dir w&euml;llt d\'Schl&euml;sselwuert
 <b>@titre_mot@</b> (@type_mot@) l&auml;schen. D&euml;st Wuert ass un <b>@texte_lie@</b> gebonnen, dir musst d&euml;s Decisioun best&auml;tegen:',
'info_derniere_etape' => '&Euml;t ass f&auml;rdeg!',
'info_derniere_syndication' => 'L&auml;scht Syndicatioun vun d&euml;sem Site den',
'info_derniers_articles_publies' => '&Auml;r l&auml;scht publiz&eacute;iert Artikelen',
'info_desactiver_forum_public' => 'D&eacute;i &ouml;ffentl&euml;ch Forum\'en ausschalten. &Ouml;ffentl&euml;ch Forum\'en k&euml;nnen vu Fall zu Fall pro Artikel ageschalt ginn; awer n&euml;t op de Rubriken, Kuerzmeldungen, asw.',
'info_desactiver_messagerie_personnelle' => 'Dir k&euml;nnt &auml;r pers&eacute;inlech Messagerie op d&euml;sem Site an- oder ausschalten.',
'info_descriptif' => 'Beschreiwung:',
'info_desinstaller_plugin' => 'l&auml;scht d\'Daten an de-aktiv&eacute;iert de Plugin',
'info_discussion_cours' => 'Aktiv Diskussiounen',
'info_ecrire_article' => 'Ier dier k&euml;nnt en Artikel schreiwen, musst dier op manst eng Rubrik derb&auml;i setzen.',
'info_email_envoi' => 'Adress vum Expediteur (optionnel)',
'info_email_envoi_txt' => 'Gitt d\'Adress un fir Email\'en ze sch&eacute;cken (als Default g&euml;t d\'Adress vum Destinataire benotzt):',
'info_email_webmestre' => 'Email-Adress vum Webmaster (optionnel)',
'info_entrer_code_alphabet' => 'Kode vum Alphabet dat benotzt soll ginn:',
'info_envoi_email_automatique' => 'Automat&euml;scht Sch&eacute;cken vun Email\'en',
'info_envoi_forum' => 'D\'Forum-Beitr&auml;g un d\'Auteuren vun den Artikelen sch&eacute;cken',
'info_envoyer_maintenant' => 'Elo sch&eacute;cken',
'info_erreur_restauration' => 'Fehler bei der Restauratioun: de Fichier g&euml;tt &euml;t n&euml;t.',
'info_etape_suivante' => 'Weider bei de n&auml;chste Schr&euml;tt',
'info_etape_suivante_1' => 'Dir k&euml;nnt bei de n&auml;chste Schr&euml;tt weidergo&euml;n.',
'info_etape_suivante_2' => 'Dir k&euml;nnt bei de n&auml;chsten Schr&euml;tt weidergo&euml;n.',
'info_exportation_base' => 'Export vun der Datebank op @archive@',
'info_facilite_suivi_activite' => 'Fir d&eacute;i editorial Aktivit&eacute;iten ze verfolgen, kann SPIP d\'Demanden fir Artikelen ze publiz&eacute;ieren oder d\'Validatiounen un eng Mailing-L&euml;scht vun de Redakteren sch&eacute;cken.',
'info_fichiers_authent' => 'Identifikatiouns-Fichier\'en ".htpasswd"',
'info_fonctionnement_forum' => 'Fonktionnement vum Forum:',
'info_forum_administrateur' => 'Forum vun den Administrateuren',
'info_forum_interne' => 'Internen Forum',
'info_forum_ouvert' => 'Am privaten Deel vum Site g&euml;t &euml;t e Forum fir d\'Redakteren. Dir k&euml;nnt hei nach e Forum, just fir d\'Administrateuren, aschalten.',
'info_forum_statistiques' => 'Statistik vun de Visiten',
'info_forums_abo_invites' => '&Auml;re Site huet Forum\'en wou een sech umelden muss; d\'Visiteuren ginn also agelueden s&euml;ch ze enregistr&eacute;ieren.',
'info_gauche_admin_effacer' => '<b>D&euml;s S&auml;it ass fir d&eacute;i Responsabel vum Site reserv&eacute;iert.</b><p>Si erlaabt d\'Maintenance-Aarbechten. Bei verschiddene Prozeduren muss een s&euml;ch iwwer FTP identifiz&eacute;ieren k&euml;nnen.</p>', # MODIF
'info_gauche_admin_tech' => '<b>D&euml;s S&auml;it ass fir d&eacute;i Responsabel vum Site reserv&eacute;iert.</b><p>Si erlaabt d\'Maintenance-Aarbechten. Bei verschiddene Prozeduren muss een s&euml;ch iwwer FTP identifiz&eacute;ieren k&euml;nnen.</p>', # MODIF
'info_gauche_admin_vider' => '<b>D&euml;s S&auml;it ass fir d&eacute;i Responsabel vum Site reserv&eacute;iert.</b><p>Si erlaabt d\'Maintenance-Aarbechten. Bei verschiddene Prozeduren muss een s&euml;ch iwwer FTP identifiz&eacute;ieren k&euml;nnen.</p>', # MODIF
'info_gauche_auteurs' => 'Hei fannt dir all d\'Auteur\'en vum Site.
Hiren Zoustand ass duerch d\'Faarw ugewisen (Administrateur = gr&eacute;ng; Redakter = giel).',
'info_gauche_auteurs_exterieurs' => 'D&eacute;i extern Auteuren ouni Zougang zum Site sinn mat enger bloer Ikone mark&eacute;iert, d&eacute;i gel&auml;schten Auteuren mat enger Drecksk&euml;scht.',
'info_gauche_messagerie' => 'D\'Messagerie erlaabt Iech Messagen un d\'Redakteren ze sch&eacute;cken, privat Notizen ze maachen oder Annoncen op d\'Starts&auml;it vum privaten Deel ze s&auml;tzen (wann d&euml;r Administrateur sidd).',
'info_gauche_numero_auteur' => 'AUTEUR NUMMER',
'info_gauche_numero_breve' => 'KUERZMELDUNG NUMMER',
'info_gauche_statistiques_referers' => 'D&euml;s S&auml;it weist d\'L&euml;scht vun de <i>Referer</i>, d&eacute;i Siten wou e Link op &auml;ren Site geklickt gouf, awer n&euml;mmen fir haut: d&euml;s L&euml;scht g&euml;t all 24 Stonnen op Null gesaat.',
'info_gauche_suivi_forum' => 'D\'S&auml;it <i>Gestioun Forum\'en</i> ass fir d\'Maintenance (an n&euml;t fir ze diskut&eacute;ieren oder ze schreiwen). Si weist all d\'Beitr&auml;g vum &ouml;ffentl&euml;che Forum fir d&euml;sen Artikel an erlaabt d&euml;s Beitr&auml;g ze g&eacute;r&eacute;ieren.',
'info_gauche_suivi_forum_2' => 'D\'S&auml;it <i>Suivi Forum\'en</i> erlaabt d\'Gestioun (a n&euml;t diskut&eacute;ieren oder schreiwen). Si weist all d\'Beitr&auml;g vun de Forum\'en vum Site, d&eacute;i &ouml;ffentl&euml;ch an d&eacute;i privat, an dir k&euml;nnt d\'Beitr&auml;g g&eacute;r&eacute;ieren.',
'info_gauche_visiteurs_enregistres' => 'Hei sinn d&eacute;i ageschriwen Visiteuren vum &ouml;ffentl&euml;chen Deel (Forum\'en op Abonnement).',
'info_generation_miniatures_images' => 'Miniaturen vun de Biller maachen',
'info_gerer_trad' => 'Iwwersetzungs-Linken aschalten?',
'info_groupe_important' => 'Wichtege Grupp',
'info_hebergeur_desactiver_envoi_email' => 'Verschidden Provider\'en erlaaben n&euml;t automat&euml;sch Email\'en ze sch&eacute;cken. An deem Fall fonktionn&eacute;iert dat hei n&euml;t.',
'info_hier' => 'g&euml;schter:',
'info_historique' => 'Versiounen:',
'info_historique_activer' => 'Versioning aschalten',
'info_historique_affiche' => 'Nei Versioun weisen',
'info_historique_comparaison' => 'Verglach',
'info_historique_desactiver' => 'Versioning ausschalten',
'info_historique_lien' => 'Historique vun den &Auml;nnerungen weisen',
'info_historique_texte' => 'De Versioning erlaabt den Historique vun allen &Auml;nnerungen vun engem Artikel an d\'Uweisen vun den &Euml;nnerscheeder t&euml;schent de Versiounen.',
'info_historique_titre' => 'Versioning',
'info_identification_publique' => '&Auml;r &ouml;ffentl&euml;ch Identit&eacute;it...',
'info_image_process' => 'Wielt d&eacute;i bescht Method fir Vignetten ze maachen an deem dier op d\'Bild klickt.',
'info_image_process2' => '<b>N.B.</b> <i>Wan dier kee Bild gesidd, dann ass de Server n&euml;t fir d&euml;s Fonktionnalit&eacute;it konfigur&eacute;iert. Wann dir se w&euml;llt benotzen, kontakt&eacute;iert een Techniker a froot fir d\'Extensiounen "GD" oder "Imagick".</i>',
'info_images_auto' => 'Automat&euml;sch berechend Biller',
'info_informations_personnelles' => 'Pers&eacute;inl&euml;ch Informatiounen',
'info_inscription_automatique' => 'Nei Redakteren automat&euml;sch aschreiwen',
'info_jeu_caractere' => 'Buchstawen-Kode vum Site',
'info_jours' => 'Deg',
'info_laisser_champs_vides' => 'd&euml;s Felder eidel loossen)',
'info_langues' => 'Sproochen vum Site',
'info_ldap_ok' => 'D\'Umeldung iwwer LDAP ass install&eacute;iert.',
'info_lien_hypertexte' => 'Link:',
'info_liens_syndiques_1' => 'Syndik&eacute;iert Linken',
'info_liens_syndiques_2' => 'waarden ob eng Validatioun.',
'info_liens_syndiques_3' => 'Forum\'en',
'info_liens_syndiques_4' => 'sinn',
'info_liens_syndiques_5' => 'Forum',
'info_liens_syndiques_6' => 'ass',
'info_liens_syndiques_7' => 'waarden op d\'Validatioun',
'info_liste_redacteurs_connectes' => 'L&euml;scht vun den ugemelden Redakteren',
'info_login_existant' => 'D&euml;se Login g&euml;t &euml;t schon.',
'info_login_trop_court' => 'De Login ass ze kuerz.',
'info_logos' => 'D\'Logo\'en',
'info_maximum' => 'Maximum:',
'info_meme_rubrique' => 'An d&euml;ser Rubrik',
'info_message' => 'Message vum',
'info_message_efface' => 'MESSAGE GEL&Auml;SCHT',
'info_message_en_redaction' => '&Auml;r Messagen an der Aarbecht',
'info_message_technique' => 'Techn&euml;schen Message:',
'info_messagerie_interne' => 'Intern Messagerie',
'info_mise_a_niveau_base' => 'Update vun &auml;rer SQL-Datebank',
'info_mise_a_niveau_base_2' => '{{Opgepasst!}} Dier hutt eng {al} Versioun vun de SPIP-Fichier\'en install&eacute;iert: &auml;r Datebank risk&eacute;iert verluer ze go&euml;n an &auml;re Site n&euml;t m&eacute;i ze fonktionn&eacute;ieren.<br />{{Install&eacute;iert d\'SPIP-Fichier\'en nach eng k&eacute;ier.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Default-Modus vun den &ouml;ffentl&euml;che Forum\'en',
'info_modifier_auteur' => 'Auteur &auml;nneren:',
'info_modifier_breve' => 'Kuerzmeldung &auml;nneren:',
'info_modifier_mot' => 'Schl&euml;sselwuert &auml;nneren:',
'info_modifier_rubrique' => 'Rubrik &auml;nneren:',
'info_modifier_titre' => '&Auml;nneren: @titre@',
'info_mon_site_spip' => 'M&auml;in SPIP-Site',
'info_mot_sans_groupe' => '(Wierder ouni Grupp...)',
'info_moteur_recherche' => 'Integr&eacute;ierten Sich-Motor',
'info_mots_cles' => 'D\'Schl&euml;sselwierder',
'info_mots_cles_association' => 'D\'Schl&euml;sselwierder vun d&euml;sem Grupp k&euml;nnen associ&eacute;iert ginn:',
'info_moyenne' => 'Moyenne:',
'info_multi_articles' => 'De Sprooch-Menu bei den Artikelen aschalten?',
'info_multi_cet_article' => 'Sprooch vun d&euml;sem Artikel:',
'info_multi_langues_choisies' => 'Wielt hei d\'Sproochen aus d&eacute;i d\'Redakteren vun &auml;rem Site k&euml;nnen benotzen.
D&eacute;i schons gebrauchten Sproochen (als &eacute;ischt ugewisen) k&euml;nnen n&euml;t ausgeschalt ginn.',
'info_multi_rubriques' => 'Sprooche-Menu bei de Rubriken aschalten?',
'info_multi_secteurs' => '... n&euml;mmen fir d\'Haapt-Rubriken?',
'info_nom' => 'Numm',
'info_nom_destinataire' => 'Numm vum Destinataire',
'info_nom_site' => 'Numm vun &auml;rem Site',
'info_nom_site_2' => '<b>Numm vun &auml;rem Site</b> [Obligatoresch]',
'info_nombre_articles' => '@nb_articles@ Artikelen,',
'info_nombre_breves' => '@nb_breves@ Kuerzmeldungen,',
'info_nombre_partcipants' => 'HUELEN UN DER DISKUSSIOUN DEEL:',
'info_nombre_rubriques' => '@nb_rubriques@ Rubriken,',
'info_nombre_sites' => '@nb_sites@ Siten,',
'info_non_deplacer' => 'N&euml;t r&eacute;ckelen...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP kann regelm&eacute;isseg eng Annonce vun de l&auml;schten Neiegkeeten vum Site sch&eacute;cken (d&eacute;i l&auml;scht publiz&eacute;iert Artikelen a Kuerzmeldungen).',
'info_non_envoi_liste_nouveautes' => 'Keng L&euml;scht vun de Neiegkeeten sch&eacute;cken',
'info_non_modifiable' => 'kann n&euml;t ge&auml;nnert ginn',
'info_non_suppression_mot_cle' => 'ech kann d&euml;st Schl&euml;sselwuert n&euml;t l&auml;schen.',
'info_notes' => 'Notizen',
'info_nouveaux_message' => 'Nei Messagen',
'info_nouvel_article' => 'Neien Artikel',
'info_nouvelle_traduction' => 'Nei Iwwersetzung:',
'info_numero_article' => 'ARTIKEL NUMMER:',
'info_obligatoire_02' => '[Obligatoresch]',
'info_option_accepter_visiteurs' => 'D\'Aschreiwung vu Visiteuren unhuelen',
'info_option_email' => 'Wann e Visiteur vum Site e neie Message an de Forum vun engem Artikel sch&eacute;ckt kennen d\'Auteuren vum Artikel via Email Bescheed kr&eacute;ien. W&euml;llt dir d&euml;s Optioun benotzen?',
'info_option_faire_suivre' => 'D\'Messagen vun de Forum\'en un d\'Auteuren vun den Artikelen sch&eacute;cken',
'info_option_ne_pas_accepter_visiteurs' => 'D\'Aschreiwung vu Visiteuren refus&eacute;ieren',
'info_option_ne_pas_faire_suivre' => 'D\'Messagen vun de Forum\'en n&euml;t sch&eacute;cken',
'info_options_avancees' => 'FORTGESCHR&Euml;TTEN OPTIOUNEN',
'info_ortho_activer' => 'D\'Orthographie aschalten',
'info_ortho_desactiver' => 'D\'Orthographie ausschalten',
'info_ou' => 'oder...',
'info_oui_suppression_mot_cle' => 'ech w&euml;ll d&euml;st Schl&euml;sselwuert definitiv l&auml;schen.',
'info_page_interdite' => 'S&auml;it gespaart',
'info_par_nom' => 'no Numm',
'info_par_nombre_article' => 'no Zuel vun den Artikelen',
'info_par_statut' => 'no Status',
'info_par_tri' => '\'(no @tri@)\'',
'info_pas_de_forum' => 'keen Forum',
'info_passe_trop_court' => 'Passwuert ze kuerz.',
'info_passes_identiques' => 'D&eacute;i zwee Passwierder si n&euml;t selwecht.',
'info_pense_bete_ancien' => '&Auml;r al Notizen', # MODIF
'info_plus_cinq_car' => 'm&eacute;i w&eacute;i 5 Buchstawen',
'info_plus_cinq_car_2' => '(M&eacute;i w&eacute;i 5 Buchstawen)',
'info_plus_trois_car' => '(M&eacute;i w&eacute;i 3 Buchstawen)',
'info_popularite' => 'Popularit&eacute;it:&nbsp;@popularite@; Visiten:&nbsp;@visites@',
'info_popularite_2' => 'Popularit&eacute;it vum Site:',
'info_popularite_3' => 'Popularit&eacute;it:&nbsp;@popularite@; Visiten:&nbsp;@visites@',
'info_popularite_4' => 'Popularit&eacute;it:&nbsp;@popularite@; Visiten:&nbsp;@visites@',
'info_post_scriptum' => 'Post-Scriptum',
'info_post_scriptum_2' => 'Post-scriptum:',
'info_pour' => 'fir',
'info_preview_admin' => 'N&euml;mmen d\'Administrateuren k&euml;nnen de Site pr&eacute;visualis&eacute;ieren',
'info_preview_comite' => 'All d\'Redakteren k&euml;nnen de Site previsualis&eacute;ieren',
'info_preview_desactive' => 'D\'Pr&eacute;visualisatioun ass ausgeschalt',
'info_preview_texte' => 'Dir k&euml;nnt de Site pr&eacute;visualis&eacute;ieren w&eacute;i wann all d\'Artikelen an d\'Kuerzmeldungen (d&eacute;i op manst de Status "props&eacute;iert" hunn) publiz&eacute;iert w&auml;ren. Soll d&euml;s M&eacute;iglechkeet fir just d\'Administrateuren, fir all d\'Redakteren oder fir keen g&euml;llen.',
'info_principaux_correspondants' => '&Auml;r wichtegst Korrespondenten',
'info_procedez_par_etape' => 'gidd Schr&euml;tt fir Schr&euml;tt fir',
'info_procedure_maj_version' => 'D\'Update-Prozedur muss ausgef&eacute;iert ginn fir &auml;r Datebank un d&eacute;i nei SPIP-Versioun unzepassen.',
'info_proxy_ok' => 'Test vum Proxy OK.',
'info_ps' => 'P.S.',
'info_publier' => 'fr&auml;ischalten',
'info_publies' => '&Auml;r publiz&eacute;iert Artikelen',
'info_question_accepter_visiteurs' => 'Wann &auml;r Skeletter d\'Aschreiwung vu Visiteuren ouni Zougang op de privaten Deel virgesinn, da schalt d\'Optioun hei dr&euml;nner an:',
'info_question_activer_compactage_css' => 'W&euml;ll dir d\'Kompressioun vun de Style-Sheets (CSS) aschalten?',
'info_question_activer_compactage_js' => 'W&euml;llt dir d\'Kompressioun vun de Skripter (Javascript) aschalten?',
'info_question_activer_compresseur' => 'W&euml;llt dir d\'Kompressioun vum HTTP-Flow aschalten?',
'info_question_gerer_statistiques' => 'Soll &auml;re Site d\'Statistik vun de Visiten g&eacute;r&eacute;ieren?',
'info_question_inscription_nouveaux_redacteurs' => 'Accept&eacute;iert dier d\'Aschreiwe vu neie Redakteren direkt vum &ouml;ffentl&euml;che Site? Wa jo, da k&euml;nnen d\'Visiteuren s&euml;ch iwert een automat&euml;sche Formulaire aschreiwen an esou Zougang op de privaten Deel kr&eacute;ien fir hir Artikelen ze propos&eacute;ieren. <blockquote><i>W&auml;hrend der Aschreiwungs-Phase kr&eacute;ien d\'Benotzer automat&euml;sch en Email mat hieren Zougangsinformatiounen. Verschidde Provideren verbidden d\'Sch&eacute;cken vun Email vun hieren Serveren aus: an deem Fall ass d\'automat&euml;scht Aschreiwen onm&eacute;iglech.', # MODIF
'info_question_mots_cles' => 'W&euml;llt dir Schl&euml;sselwierder op &auml;rem Site benotzen?',
'info_question_proposer_site' => 'Wie kann e Site propos&eacute;ieren?',
'info_question_utilisation_moteur_recherche' => 'W&euml;llt dir de Sich-Motor vu SPIP benotzen?
(ausschalten m&euml;cht de System m&eacute;i s&eacute;ier.)',
'info_question_vignettes_referer' => 'Wann dir d\'Statistik kuckt k&euml;nnt dir eng Preview vun den Ausgangs-Site gesinn',
'info_question_vignettes_referer_non' => 'D\'Preview vun den Ausgangs-Site n&euml;t weisen',
'info_question_vignettes_referer_oui' => 'Preview vun den Ausgangs-Site weisen',
'info_question_visiteur_ajout_document_forum' => 'Wann dir de Visiteuren erlaabt Dokumenter (Biller, Toun...) b&auml;i e Forum-Message ze setzen, da gitt hei un w&eacute;i eng Extensiounen am Forum erlaabt sin (z.B.: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Wann dir all Dokument-Formater als s&euml;cher ukuckt, dann gitt e St&auml;r an. Fir n&auml;ischt ze erlaaben, gitt n&auml;ischt an.',
'info_qui_attribue_mot_cle' => 'D\'Wierder vun d&euml;sem Grupp k&euml;nne verdeelt ginn vun:',
'info_racine_site' => 'Wuerzel vum Site',
'info_recharger_page' => 'Lued d&euml;s S&auml;it an e puer Sekonnen nei.',
'info_recherche_auteur_a_affiner' => 'Zevill Resultater fir "@cherche_auteur@"; verbessert &auml;r Sich.',
'info_recherche_auteur_ok' => 'E puer Redakteren fonnt fir "@cherche_auteur@":',
'info_recherche_auteur_zero' => '<b>Keen Resultat fir "@cherche_auteur@".',
'info_recommencer' => 'F&auml;nkt weg nei un.',
'info_redacteur_1' => 'Redakter',
'info_redacteur_2' => 'mat Zougang zum privaten Deel (<i>recommand&eacute;iert</i>)',
'info_redacteurs' => 'Redakteren',
'info_redaction_en_cours' => 'AN DER AARBECHT',
'info_redirection' => '&Euml;mledung',
'info_referencer_doc_distant' => 'En Dokument vum Internet referenz&eacute;ieren:',
'info_refuses' => '&Auml;r refus&eacute;iert Artikelen',
'info_reglage_ldap' => 'Optiounen: <b>Astellen vum LDAP-Import</b>',
'info_renvoi_article' => '<b>&Euml;mledung.</b> D&euml;sen Artikel weist op d\'S&auml;it:',
'info_reserve_admin' => 'N&euml;mmen d\'Administrateuren k&euml;nnen d&euml;s Adress &auml;nneren.',
'info_restauration_sauvegarde' => 'Restauratioun vum Backup @archive@',
'info_restauration_sauvegarde_insert' => 'Insert vum @archive@ an d\'Datebank',
'info_restreindre_rubrique' => 'D\'Gestioun aschr&auml;nken op d\'Rubrik:',
'info_resultat_recherche' => 'Resultater vun der Sich:',
'info_rubriques' => 'Rubriken',
'info_rubriques_02' => 'Rubriken',
'info_rubriques_liees_mot' => 'Un d&euml;st Schl&euml;sselwuert gebonnen Rubriken',
'info_rubriques_trouvees' => 'Rubriken fonnt',
'info_rubriques_trouvees_dans_texte' => 'Rubriken fonnt (am Text)',
'info_sans_titre' => 'Ouni Titel',
'info_sauvegarde' => 'Backup',
'info_sauvegarde_articles' => 'Artikelen sp&auml;icheren',
'info_sauvegarde_articles_sites_ref' => 'Artikelen vun de referenz&eacute;ierten Siten sp&auml;icheren',
'info_sauvegarde_auteurs' => 'Auteuren sp&auml;icheren',
'info_sauvegarde_breves' => 'Kuerzmeldungen sp&auml;icheren',
'info_sauvegarde_documents' => 'Dokumenter sp&auml;icheren',
'info_sauvegarde_echouee' => 'Wann de Backup n&euml;t fonktionn&eacute;iert ("Maximum execution time exceeded"),',
'info_sauvegarde_forums' => 'Forum\'en sp&auml;icheren',
'info_sauvegarde_groupe_mots' => 'Schl&euml;sselwierder-Gruppen sp&auml;icheren',
'info_sauvegarde_messages' => 'Messagen sp&auml;icheren',
'info_sauvegarde_mots_cles' => 'Schl&euml;sselwierder sp&auml;icheren',
'info_sauvegarde_petitions' => 'Petitiounen sp&auml;icheren',
'info_sauvegarde_refers' => 'Referer\'en sp&auml;icheren',
'info_sauvegarde_reussi_01' => 'Backup f&auml;rdeg.',
'info_sauvegarde_reussi_02' => 'De Backup vun der Datebank ass @archive@. Dir k&euml;nnt',
'info_sauvegarde_reussi_03' => 'zer&euml;ck bei d\'Gestioun',
'info_sauvegarde_reussi_04' => 'vun &auml;rem Site.',
'info_sauvegarde_rubrique_reussi' => 'D\'Tafelen vun der Rubrik @titre@ sinn am @archive@ gesp&auml;ichert. Dir k&euml;nnt',
'info_sauvegarde_rubriques' => 'Rubriken sp&auml;icheren',
'info_sauvegarde_signatures' => '&Euml;nnerschr&euml;ften vun de Petitiounen sp&auml;icheren',
'info_sauvegarde_sites_references' => 'Referenz&eacute;iert Siten sp&auml;icheren',
'info_sauvegarde_type_documents' => 'Dokument-Typen sp&auml;icheren',
'info_sauvegarde_visites' => 'Visiten sp&auml;icheren',
'info_selection_chemin_acces' => '<b>Wielt</b> hei de Wee fir den Annuaire:',
'info_selection_un_seul_mot_cle' => 'Dir k&euml;nnt <b>&euml;mmer n&euml;mmen een Schl&euml;sselwuert</b> an d&euml;sem Grupp wielen.',
'info_signatures' => '&Euml;nnerschr&euml;ften',
'info_site' => 'Site',
'info_site_2' => 'Site:',
'info_site_min' => 'Site',
'info_site_propose' => 'Site propos&eacute;iert den:',
'info_site_reference_2' => 'Referenz&eacute;ierten Site',
'info_site_syndique' => 'D&euml;se Site ass syndiqu&eacute;iert...',
'info_site_valider' => 'Siten ze valid&eacute;ieren',
'info_site_web' => 'SITE:',
'info_sites' => 'Siten',
'info_sites_lies_mot' => 'Un d&euml;st Schl&euml;sselwuert gebonnen referenz&eacute;iert Siten',
'info_sites_proxy' => 'Proxy benotzen',
'info_sites_refuses' => 'D&eacute;i refus&eacute;iert Siten',
'info_sites_trouves' => 'Siten fonnt',
'info_sites_trouves_dans_texte' => 'Siten fonnt (am Text)',
'info_sous_titre' => '&Euml;nnertitel:',
'info_statut_administrateur' => 'Administrateur',
'info_statut_auteur' => 'Statut vun d&euml;sem Auteur:',
'info_statut_auteur_a_confirmer' => 'Umeldung ze konfirm&eacute;ieren',
'info_statut_auteur_autre' => 'Aneren Status:',
'info_statut_efface' => 'Gel&auml;scht',
'info_statut_redacteur' => 'Redakter',
'info_statut_site_1' => 'D&euml;se Site ass:',
'info_statut_site_2' => 'Publiz&eacute;iert',
'info_statut_site_3' => 'Propos&eacute;iert',
'info_statut_site_4' => 'An der Drecksk&euml;scht',
'info_statut_utilisateurs_1' => 'Default-Status vun den import&eacute;ierten Auteuren',
'info_statut_utilisateurs_2' => 'Wielt de Status vun den Persounen aus dem LDAP-Annuaire d&eacute;i sech fir d\'&eacute;ischt umelden. Dier k&euml;nnt duerno d&euml;s Valeur pro Auteur &auml;nneren.',
'info_suivi_activite' => 'Suivi vun der editorialer Aktivit&eacute;it',
'info_supprimer_mot' => 'd&euml;st&nbsp;Wuert&nbsp;l&auml;schen',
'info_surtitre' => 'Iwwertitel:',
'info_syndication_integrale_1' => '&Auml;re Site propos&eacute;iert Syndicatiouns-Fichier\'en (kuckt op "<a href="@url@">@titre@</a>").',
'info_syndication_integrale_2' => 'W&euml;llt dir d\'Artikelen ganz oder n&euml;mmen e R&eacute;sum&eacute; vun e puer honnert Buchstawen iwerdro&euml;n?',
'info_table_prefix' => 'Dir k&euml;nnt de Pr&eacute;fixe vun den Tabellen &auml;nneren (dat musst dir maachen wann dir e puer Siten op derselwechter Datebank w&euml;llt install&eacute;ieren). De Pr&eacute;fixe muss kl&eacute;ng Buchstawen hun, ouni Accent an ouni Leerzeechen.',
'info_taille_maximale_images' => 'SPIP test d\'Maximalgr&eacute;isst vun de Biller d&eacute;i hien verarbechte kann (a Millioune Pixel).<br /> Biller d&eacute;i m&eacute;i grouss sinn ginn n&euml;t reduz&eacute;iert.',
'info_taille_maximale_vignette' => 'Maximal-Gr&eacute;isst vun de Vignetten d&eacute;i vum System gemaach ginn:',
'info_terminer_installation' => 'Dier k&euml;nnt elo d&eacute;i normal Installatiouns-Prozedur ofschl&eacute;issen.',
'info_texte' => 'Text',
'info_texte_explicatif' => 'Erkl&auml;rung',
'info_texte_long' => '(den Text ass laang: en ass an e puer St&eacute;cker d&eacute;i bei der Validatioun zesummen gepecht ginn.)',
'info_texte_message' => 'Text vun &auml;rem Message:',
'info_texte_message_02' => 'Text vun &auml;rem Message',
'info_titre' => 'Titel:',
'info_titre_mot_cle' => 'Numm oder Titel vum Schl&euml;sselwuert',
'info_total' => 'Total:',
'info_tous_articles_en_redaction' => 'All d\'Artikelen an der Aarbecht',
'info_tous_articles_presents' => 'All d\'Artikelen d&eacute;i an d&euml;ser Rubrik publiz&eacute;iert sinn',
'info_tous_articles_refuses' => 'Tous les articles refus&eacute;s', # NEW
'info_tous_les' => 'all:',
'info_tous_redacteurs' => 'Annoncen un all d\'Redakteren',
'info_tout_site' => 'De ganzen Site',
'info_tout_site2' => 'D&euml;sen Artikel ass n&euml;t an d&eacute;i Sprooch iwwersaat.',
'info_tout_site3' => 'Den Artikel ass an d&eacute;i Sprooch iwwersaat, mais de Referenz-Artikel ass ge&auml;nnert ginn. D\'Iwwersetzung muss och ge&auml;nnert ginn.',
'info_tout_site4' => 'Den Artikel ass an d&eacute;i Sprooch iwwersaat, an d\'Iwwersetzung ass &agrave; jour.',
'info_tout_site5' => 'Original-Artikel.',
'info_tout_site6' => '<b>Opgepasst:</b> n&euml;mmen d\'Original-Artikelen si gewisen. D\'Iwwersetzungen geh&eacute;ieren zum Original, mat enger Faarw d&eacute;i hieren Zoustand weist:',
'info_travail_colaboratif' => 'Zesummenaarbecht bei den Artikelen',
'info_un_article' => 'en Artikel,',
'info_un_mot' => 'Wuert fir Wuert',
'info_un_site' => 'e Site,',
'info_une_breve' => 'eng Kuerzmeldung,',
'info_une_rubrique' => 'eng Rubrik,',
'info_une_rubrique_02' => '1 Rubrik',
'info_url' => 'URL:',
'info_url_site' => 'URL VUM SITE:',
'info_urlref' => 'Link:',
'info_utilisation_spip' => 'Dir k&euml;nnt elo de System benotzen...',
'info_visites_par_mois' => 'Visiten pro Mount:',
'info_visites_plus_populaires' => 'Visiten weisen fir <b>d&eacute;i popul&auml;rsten</b> a fir <b>d&eacute;i l&auml;scht publiz&eacute;iert</b> Artikelen:',
'info_visiteur_1' => 'Visiteur',
'info_visiteur_2' => 'vum &ouml;ffentl&euml;che Site',
'info_visiteurs' => 'Visiteuren',
'info_visiteurs_02' => 'Visiteuren vum &ouml;ffentl&euml;che Site',
'install_adresse_base_hebergeur' => 'Adress vun der Datebank d&eacute;i dir vum Hosting krut',
'install_base_ok' => 'D\'Datebank @base@ ass erkannt ginn',
'install_echec_annonce' => 'D\'Installatioun w&auml;rt warscheinlech n&euml;t fonktionn&eacute;ieren oder zu engem fehlerhaften Site f&eacute;ieren...',
'install_extension_mbstring' => 'SPIP fonktionn&eacute;iert n&euml;t mat:',
'install_extension_php_obligatoire' => 'SPIP brauch d\'PHP-Extensioun:',
'install_login_base_hebergeur' => 'Login fir d\'Verbindung deen dir vum Hosting krut',
'install_nom_base_hebergeur' => 'Num vun der Datebank d&eacute;i dir vum Hosting krut:',
'install_pas_table' => 'Datebank ouni Tafelen',
'install_pass_base_hebergeur' => 'Passwuert vun der Verbindung dat dir vum Hosting krut',
'install_php_version' => 'PHP-Version @version@ geet n&euml;t duer (Minimum = @minimum@)',
'install_select_langue' => 'Wielt eng Sprooch a klickt op de Kn&auml;ppchen "Weider" fir d\'Installatioun ze starten.',
'install_select_type_db' => 'Gidd den Typ vun der Datebank un:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL', # NEW
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Datebankserver vum Hosting zougewisen',
'install_table_prefix_hebergeur' => 'Pr&eacute;fixe vun den Tafelen deen dir vum Hosting krut:',
'install_tables_base' => 'Datebanktabellen',
'install_types_db_connus' => 'SPIP kann <b>MySQL</b> (am w&auml;iteste verbreed), <b>PostgreSQL</b> an <b>SQLite</b> benotzen.',
'install_types_db_connus_avertissement' => 'Opgepasst: verschidde Plugin\'en fonktionn&eacute;iere n&euml;mmen mat MySQL',
'intem_redacteur' => 'Redakter',
'intitule_licence' => 'Lizenz',
'item_accepter_inscriptions' => 'Aschreiwungen unhuelen',
'item_activer_forum_administrateur' => 'De Forum vun den Adminstrateuren aschalten',
'item_activer_messages_avertissement' => 'Warnungen aschalten',
'item_administrateur_2' => 'Administrateur',
'item_afficher_calendrier' => 'Am Kalenner weisen',
'item_ajout_mots_cles' => 'Schl&euml;sselwierder an de Forum\'en erlaben',
'item_autoriser_documents_joints' => 'Dokumenter bei den Artikelen erlaben',
'item_autoriser_documents_joints_rubriques' => 'Dokumenter an de Rubriken erlaben',
'item_autoriser_selectionner_date_en_ligne' => 'Erlaaben den Datum vun all Dokument ze &auml;nneren',
'item_autoriser_syndication_integrale' => 'D\'Artikelen ganz an de Syndicatiouns-Fichier\'en iwerdro&euml;n',
'item_bloquer_liens_syndiques' => 'D&eacute;i syndiqu&eacute;iert Linken fir eng Validatioun block&eacute;ieren',
'item_breve_refusee' => 'NEEN - Kuerzmeldung refus&eacute;iert',
'item_breve_validee' => 'JO - Kuerzmeldung valid&eacute;iert',
'item_choix_administrateurs' => 'd\'Administrateuren',
'item_choix_generation_miniature' => 'Automat&euml;sch Miniaturen vun de Biller maachen.',
'item_choix_non_generation_miniature' => 'Keng Miniaturen vun de Biller maachen.',
'item_choix_redacteurs' => 'd\'Redakteren',
'item_choix_visiteurs' => 'd\'Visiteuren vum &ouml;ffentl&euml;che Site',
'item_compresseur' => 'Kompressioun aschalten',
'item_config_forums_prive_global' => 'De Redaktor-Forum aschalten',
'item_config_forums_prive_objets' => 'Forumen aschalten',
'item_creer_fichiers_authent' => 'D\'Fichier\'en .htpasswd maachen',
'item_desactiver_forum_administrateur' => 'De Forum vun den Administrateuren ofschalten',
'item_gerer_annuaire_site_web' => 'Eng Link-Sammlung maachen',
'item_gerer_statistiques' => 'Statistik maachen',
'item_limiter_recherche' => 'D\'Sich vun den Informatiounen op &auml;re Site limit&eacute;ieren',
'item_login' => 'Login',
'item_messagerie_agenda' => 'D\'Messagerie an den Agenda aschalten',
'item_mots_cles_association_articles' => 'vun den Artikelen',
'item_mots_cles_association_breves' => 'vun de Kuerzmeldungen',
'item_mots_cles_association_rubriques' => 'vun de Rubriken',
'item_mots_cles_association_sites' => 'vun de referenz&eacute;ierten oder syndiqu&eacute;ierten Siten.',
'item_non' => 'Neen',
'item_non_accepter_inscriptions' => 'Keng Aschreiwung unhuelen',
'item_non_activer_messages_avertissement' => 'Keng Warnungen',
'item_non_afficher_calendrier' => 'Kee Kalenner weisen',
'item_non_ajout_mots_cles' => 'D\'Schl&euml;sselwierder an de Forum\'en verbidden',
'item_non_autoriser_documents_joints' => 'Keng Dokumenter bei den Artikelen erlaben',
'item_non_autoriser_documents_joints_rubriques' => 'Keng Dokumenter an de Rubriken erlaben',
'item_non_autoriser_selectionner_date_en_ligne' => 'Den Datum vun den Dokumenter ass deen w&eacute;ini s&euml; op de Site gesaat goufen',
'item_non_autoriser_syndication_integrale' => 'N&euml;mmen e R&eacute;sum&eacute; iwerdro&euml;n',
'item_non_bloquer_liens_syndiques' => 'D\'Linken aus der Syndicatioun n&euml;t block&eacute;ieren',
'item_non_compresseur' => 'Kompressioun ausschalten',
'item_non_config_forums_prive_global' => 'De Redaktor-Forum ausschalten',
'item_non_config_forums_prive_objets' => 'Forumen ausschalten',
'item_non_creer_fichiers_authent' => 'D&euml;s Fichier\'en n&euml;t maachen',
'item_non_gerer_annuaire_site_web' => 'D\'Link-Sammlung ausschalten',
'item_non_gerer_statistiques' => 'D\'Statistik ausschalten',
'item_non_limiter_recherche' => 'D\'Sich op den Inhalt vun de referenz&eacute;ierten Siten erweideren',
'item_non_messagerie_agenda' => 'D\'Messagerie an den Agenda ausschalten',
'item_non_publier_articles' => 'D\'Artikelen n&euml;t virun dem Publikatiouns-Datum fr&auml;ischalten.',
'item_non_utiliser_breves' => 'D\'Kuerzmeldungen ausschalten',
'item_non_utiliser_config_groupe_mots_cles' => 'D&eacute;i erweidert Konfiguratioun vun de Schl&euml;sselwierder ausschalten',
'item_non_utiliser_moteur_recherche' => 'De Sich-Motor ausschalten',
'item_non_utiliser_mots_cles' => 'D\'Schl&euml;sselwierder ausschalten',
'item_non_utiliser_syndication' => 'D&eacute;i automatesch Syndicatioun ausschalten',
'item_nouvel_auteur' => 'Neien Auteur',
'item_nouvelle_breve' => 'Nei Kuerzmeldung',
'item_nouvelle_rubrique' => 'Nei Rubrik',
'item_oui' => 'Jo',
'item_publier_articles' => 'D\'Artikelen, egal w&eacute;i e Publikatiouns-Datum, fr&auml;ischalten',
'item_reponse_article' => '&Auml;ntwert op den Artikel',
'item_utiliser_breves' => 'D\'Kuerzmeldungen aschalten',
'item_utiliser_config_groupe_mots_cles' => 'D&eacute;i erweidert Konfiguratioun vun de Schl&euml;sselwierder aschalten',
'item_utiliser_moteur_recherche' => 'De Sich-Motor aschalten',
'item_utiliser_mots_cles' => 'D\'Schl&euml;sselwierder aschalten',
'item_utiliser_syndication' => 'D&eacute;i automatesch Syndicatioun aschalten',
'item_visiteur' => 'Visiteur',

// J
'jour_non_connu_nc' => '?',

// L
'ldap_correspondance' => 'h&eacute;ritage du champ @champ@', # NEW
'ldap_correspondance_1' => 'H&eacute;ritage des champs LDAP', # NEW
'ldap_correspondance_2' => 'Pour chacun des champs SPIP suivants, indiquer le nom du champ LDAP correspondant. Laisser vide pour ne pas le remplir, s&eacute;parer par des espaces ou des virgules pour essayer plusieurs champs LDAP.', # NEW
'lien_ajout_destinataire' => 'Destinataire derb&auml;i setzen',
'lien_ajouter_auteur' => 'D&euml;sen Auteur derb&auml;i setzen',
'lien_ajouter_participant' => 'E Mataarbechter derb&auml;i setzen',
'lien_email' => 'Email',
'lien_forum_public' => '&Ouml;ffentl&euml;che Forum vum Artikel aschalten',
'lien_mise_a_jour_syndication' => 'Elo updaten',
'lien_nom_site' => 'NUMM VUM SITE:',
'lien_nouvelle_recuperation' => 'Eng nei Restauratioun vun den Daten prob&eacute;ieren',
'lien_reponse_article' => '&Auml;ntwert op den Artikel',
'lien_reponse_breve' => '&Auml;ntwert op d\'Kuerzmeldung',
'lien_reponse_breve_2' => '&Auml;ntwert op d\'Kuerzmeldung',
'lien_reponse_rubrique' => '&Auml;ntwert op d\'Rubrik',
'lien_reponse_site_reference' => '&Auml;ntwert op de referenz&eacute;ierten Site:',
'lien_retirer_auteur' => 'Auteur l&auml;schen',
'lien_retrait_particpant' => 'Mataarbechter l&auml;schen',
'lien_site' => 'Site',
'lien_supprimer_rubrique' => 'd&euml;s Rubrik l&auml;schen',
'lien_tout_deplier' => 'Alles opklappen',
'lien_tout_replier' => 'Alles zouklappen',
'lien_tout_supprimer' => 'Alles l&auml;schen',
'lien_trier_nom' => 'No Numm sort&eacute;ieren',
'lien_trier_nombre_articles' => 'No Zuel vun den Artikelen sort&eacute;iren',
'lien_trier_statut' => 'No Status sort&eacute;ieren',
'lien_voir_en_ligne' => 'ONLINE KUCKEN:',
'logo_article' => 'LOGO VUM ARTIKEL',
'logo_auteur' => 'LOGO VUM AUTEUR',
'logo_breve' => 'LOGO VUN DER KUERZMELDUNG',
'logo_mot_cle' => 'LOGO VUM SCHL&Euml;SSELWUERT',
'logo_rubrique' => 'LOGO VUN DER RUBRIK',
'logo_site' => 'LOGO VUM SITE',
'logo_standard_rubrique' => 'STANDARD-LOGO VUN DE RUBRIKEN',
'logo_survol' => 'LOGO FIR DE MOUSEOVER',

// M
'menu_aide_installation_choix_base' => 'Wiel vun &auml;rer Datebank',
'module_fichier_langue' => 'Sprooche-Fichier',
'module_raccourci' => 'Ofkiirzung',
'module_texte_affiche' => 'Gewisenen Text',
'module_texte_explicatif' => 'Dir k&euml;nnt d&euml;s Ofkiirzungen an de Skelett vum &ouml;ffentl&euml;che Site abauen. Si ginn automat&euml;sch an d&eacute;i Sproochen iwwersat wou &euml;t e Sprooche-Fichier g&euml;tt.',
'module_texte_traduction' => 'De Sprooche-Fichier &laquo;&nbsp;@module@&nbsp;&raquo; g&euml;tt et op:',
'mois_non_connu' => 'onbekannt',

// N
'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW

// O
'onglet_contenu' => 'Inhalt',
'onglet_declarer_une_autre_base' => 'Eng aner Datebank d&eacute;clar&eacute;ieren',
'onglet_discuter' => 'Diskut&eacute;ieren',
'onglet_documents' => 'Dokumenter',
'onglet_interactivite' => 'Interaktivit&eacute;it',
'onglet_proprietes' => 'Propri&eacute;t&eacute;iten',
'onglet_repartition_actuelle' => 'elo',
'onglet_sous_rubriques' => '&Euml;nner-Rubriken',

// P
'page_pas_proxy' => 'D&euml;s S&auml;it d&auml;rf n&euml;t duerch de Proxy',
'pas_de_proxy_pour' => 'Wa n&eacute;ideg dann gidd d&eacute;i Maschinen oder Domainer un fir d&eacute;i d&euml;se Proxy n&euml;t zielt (z.B.: @exemple@)',
'plugin_charge_paquet' => 'De Package @name@ lueden',
'plugin_charger' => 'T&#233;l&#233;charger', # NEW
'plugin_erreur_charger' => 'Fehler: onm&eacute;iglech @zip@ ze lueden',
'plugin_erreur_droit1' => 'D\'Directory <code>@dest@</code> ass n&euml;t schreiwbar.',
'plugin_erreur_droit2' => 'Kontroll&eacute;iert d\'Rechter op d&euml;ser Directory oder install&eacute;iert d\'Fichier\'en via FTP.',
'plugin_erreur_zip' => 'pclzip: Fehler @status@',
'plugin_etat_developpement' => 'an der &Euml;ntw&eacute;cklung',
'plugin_etat_experimental' => 'experimental',
'plugin_etat_stable' => 'stabil',
'plugin_etat_test' => 'am Test',
'plugin_impossible_activer' => 'De Plugin @plugin@ ka n&euml;t aktiv&eacute;iert ginn',
'plugin_info_automatique1' => 'Wann dir d\'automat&euml;sch Installatioun vun Plugin\'e erlaabt, dann:',
'plugin_info_automatique1_lib' => 'Si vous souhaitez autoriser l\'installation automatique de cette librairie, veuillez&nbsp;:', # NEW
'plugin_info_automatique2' => 'erstellt de R&eacute;pertoire <code>@rep@</code>;',
'plugin_info_automatique3' => 'kontroll&eacute;iert op de Server kann an d&euml;se Repertoire schreiwen.',
'plugin_info_automatique_creer' => 'am Root-Repertoire vum Site ze erstellen.',
'plugin_info_automatique_exemples' => 'Beispiller:',
'plugin_info_automatique_ftp' => 'Dir k&euml;nnt d\'Plugin\'e per FTP an de Repertoire <tt>@rep@</tt> install&eacute;iren',
'plugin_info_automatique_lib' => 'Verschidde Plugin\'e musse k&euml;nne Fichier\'en an de Repertoire <code>lib/</code> eroflueden, eventuell am Root-Repertoire vum Site ze erstellen.',
'plugin_info_automatique_liste' => '&Auml;r Plugin-L&euml;scht:',
'plugin_info_automatique_liste_officielle' => 'd&eacute;i offiziell Plugin\'e',
'plugin_info_automatique_liste_update' => 'L&euml;schten updaten',
'plugin_info_automatique_ou' => 'oder...',
'plugin_info_automatique_select' => 'Wielt e Plugin: SPIP lued en erof an install&eacute;iert en am Repertoire <code>@rep@</code>; wann de Plugin schons do ass g&euml;tt en Update gemaach.',
'plugin_info_extension_1' => 'Les extensions ci-dessous sont charg&#233;es et activ&#233;es dans le r&#233;pertoire @extensions@.', # NEW
'plugin_info_extension_2' => 'Elles ne sont pas d&#233;sactivables.', # NEW
'plugin_info_telecharger' => 'Eroflueden vun @url@ an Installatioun an @rep@',
'plugin_librairies_installees' => 'Install&eacute;iert Librairie\'en',
'plugin_necessite_lib' => 'D&euml;se Plugin brauch d\'Librairie @lib@',
'plugin_necessite_plugin' => 'De Plugin @plugin@ muss mindestens op der Versioun @version@ sinn.',
'plugin_necessite_spip' => 'SPIP muss mindestens op der Versioun @version@ sinn.',
'plugin_source' => 'Quell:&nbsp;',
'plugin_titre_automatique' => 'Automat&euml;sch Installatioun',
'plugin_titre_automatique_ajouter' => 'Plugin\'e derb&auml;i setzen',
'plugin_titre_installation' => 'Installation du plugin @plugin@', # NEW
'plugin_zip_active' => 'Fuert weider fir ze aktiv&eacute;ieren',
'plugin_zip_adresse' => 'gidd hei d\'Adress vun engem Plugin-Zip-Fichier un, oder d\'Adress vun enger L&euml;scht vu Plugin\'e.',
'plugin_zip_adresse_champ' => 'Adress vum Plugin oder vun der L&euml;scht&nbsp;',
'plugin_zip_content' => 'Folgend Fichier\'en sinn dran (@taille@),<br />f&auml;rdeg fir am Repertoire <code>@rep@</code> install&eacute;iert ze ginn',
'plugin_zip_installe_finie' => 'De Fichier @zip@ ass entpackt an install&eacute;iert ginn.',
'plugin_zip_installe_rep_finie' => 'De Fichier @zip@ ass entpackt an am Repertoire @rep@ install&eacute;iert ginn',
'plugin_zip_installer' => 'Dir k&euml;nnt en elo install&eacute;ieren.',
'plugin_zip_telecharge' => 'De Fichier @zip@ ass erofgeluede ginn',
'plugins_actif_aucun' => 'Aucun plugin activ&#233;.', # NEW
'plugins_actif_un' => 'Un plugin activ&#233;.', # NEW
'plugins_actifs' => '@count@ aktiv&eacute;iert Plugin\'e.',
'plugins_actifs_liste' => 'Plugins actifs', # NEW
'plugins_compte' => '@count@ Plugin\'e',
'plugins_disponible_un' => 'Un plugin disponible.', # NEW
'plugins_disponibles' => '@count@ Plugin\'e verf&uuml;gbar.',
'plugins_erreur' => 'Fehler an de Plugin\'e: @plugins@',
'plugins_liste' => 'L&euml;scht vun de Plugin\'en',
'plugins_liste_extensions' => 'Extensions', # NEW
'plugins_recents' => 'Plugins r&eacute;cents.', # NEW
'plugins_vue_hierarchie' => 'Hi&eacute;rarchie',
'plugins_vue_liste' => 'L&euml;scht',
'protocole_ldap' => 'Versioun vum Protokol:',

// R
'repertoire_plugins' => 'Dossier:',

// S
'sans_heure' => 'ouni Z&auml;it',
'sauvegarde_fusionner' => 'D&eacute;i aktuell Datebank mam Backup fusionn&eacute;ieren',
'sauvegarde_fusionner_depublier' => 'D&eacute;i fusionn&eacute;iert Objekter n&euml;t m&eacute;i ver&ouml;ffentl&euml;che',
'sauvegarde_url_origine' => 'Eventuell d\'Url vum Ausgangs-Site:',
'statut_admin_restreint' => '(restriktiven Admin)',
'syndic_choix_moderation' => 'Wat soll mat de n&auml;chste Linken vun d&euml;sem Site gesch&eacute;ien?',
'syndic_choix_oublier' => 'Wat soll mat de Linken gesch&eacute;ien d&eacute;i n&euml;t m&eacute;i am Syndicatiouns-Fichier sinn?',
'syndic_choix_resume' => 'Verschidden Siten publiz&eacute;ieren de kompletten Text vun den Artikelen. Wann deen do ass, w&euml;ll dir syndiqu&eacute;ieren:',
'syndic_lien_obsolete' => 'falsche Link',
'syndic_option_miroir' => 'automatesch block&eacute;ieren',
'syndic_option_oubli' => '(no @mois@ M&eacute;int) l&auml;schen',
'syndic_option_resume_non' => 'de kompletten Inhalt vun den Artikelen (am HTML-Format)',
'syndic_option_resume_oui' => 'en einfachen R&eacute;sum&eacute; (am Text-Format)',
'syndic_options' => 'Optiounen vun der Syndicatioun:',

// T
'taille_cache_image' => 'D&eacute;i automat&euml;sch berechent Biller (Vignetten vun Dokumenter, graphesch Titelen, mathematesch Formelen am TeX-Format...) brauchen am R&eacute;pertoire @dir@ eng Plaz vun @taille@.',
'taille_cache_infinie' => 'De Cache vun d&euml;sem Site ass n&euml;t an der Gr&eacute;isst limit&eacute;iert.',
'taille_cache_maxi' => 'SPIP prob&eacute;iert d\'Gr&eacute;isst vum Cache vun d&euml;sem Site op ongef&eacute;ier <b>@octets@</b> ze limit&eacute;ieren.',
'taille_cache_octets' => 'D\'Gr&eacute;isst vum Cache ass elo @octets@.',
'taille_cache_vide' => 'De Cache ass eidel.',
'taille_repertoire_cache' => 'Gr&eacute;isst vum Cache-Dossier',
'text_article_propose_publication' => 'Fir d\'Publikatioun propos&eacute;ierten Artikel.',
'text_article_propose_publication_forum' => 'Z&euml;ckt n&euml;t &auml;r Meenung am Forum vun d&euml;sem Artikel ofzeginn (&euml;nnen op der S&auml;it).',
'texte_acces_ldap_anonyme_1' => 'Verschidden LDAP-Serveren erlaben keen anonymen Zougang. An deem Fall musst dir en initialen Zougang uginn fir Informatiounen am Annuaire k&euml;nnen ze sichen. An deenen meeschten F&auml;ll k&euml;nnt d&euml;r d&euml;s Felder eidel loossen.',
'texte_admin_effacer_01' => 'D&euml;s Prozedur l&auml;scht <i>alles</i> aus der Datebank, och <i>all</i> Zoug&auml;ng vun de Redakteren an Administrateuren. Duerno musst dir SPIP nei install&eacute;ieren fir eng nei Datebank an den &eacute;ischten Administrateur-Zougang derb&auml;i ze setzen.',
'texte_admin_effacer_stats' => 'D&euml;s Prozedur l&auml;scht d\'Statistik an d\'Popularit&eacute;it vun den Artikele vun &auml;rem Site.',
'texte_admin_tech_01' => 'D&euml;s Optioun erlaabt den Inhalt vun der Datebank am Dossier @dossier@ ze sp&auml;icheren. Vergiesst n&euml;t och de ganzen Inhalt vum Dossier @img@ erofzelueden, wou d\'Biller an d\'Dokumenter vun den Artikelen an an de Rubrike sinn.',
'texte_admin_tech_02' => 'Opgepasst: d&euml;se Backup kann n&euml;mmen op e Site mat ders&euml;lwechter SPIP-Versioun restaur&eacute;iert ginn. Versicht also nie "Datebank eidel maachen" an der Hoffnung dir kinnt se nei no engem Update install&eacute;ieren... Kuckt <a href="@spipnet@">an der SPIP-Dokumentatioun</a>.',
'texte_admin_tech_03' => 'Dir k&euml;nnt de Fichier komprim&eacute;iert sp&auml;icheren fir m&eacute;i e s&eacute;ieren Downlued oder Transfert op e Backup-Server, a fir Disk-Plaz ze spueren.',
'texte_admin_tech_04' => 'Fir mat enger anerer Datebank ze fusionn&eacute;iere k&euml;nnt dir de Backup op d&euml;s Rubrik begrenzen: ',
'texte_adresse_annuaire_1' => '(Wann &auml;ren Annuaire op ders&euml;lwechter Maschinn install&eacute;iert ass, dann as et hei warscheinl&euml;ch "localhost".)',
'texte_ajout_auteur' => 'D&euml;sen Auteur gouf beim Artikel derb&auml;i gesat:',
'texte_annuaire_ldap_1' => 'Wann dir Zougang zu engem Annuaire (LDAP) hutt, da k&euml;nnt dir e benotzen fir automat&euml;sch d\'Benotzer vu SPIP ze import&eacute;ieren.',
'texte_article_statut' => 'D&euml;sen Artikel ass:',
'texte_article_virtuel' => 'Virtuellen Artikel',
'texte_article_virtuel_reference' => '<b>Virtuellen Artikel:</b> am SPIP agedro&euml;n, mais op eng aner URL &euml;mgeleed. Fir d\'&Euml;mledung ze l&auml;schen, l&auml;scht d\'URL hei driwwer.',
'texte_aucun_resultat_auteur' => 'Kee Resultat fir "@cherche_auteur@"',
'texte_auteur_messagerie' => 'De Site kann Iech dauernd d\'L&euml;scht vun den ugemelten Redakteren weisen, fir dat dier hinnen direkt Messagen k&euml;nnt sch&eacute;cken. Dir k&euml;nnt d&eacute;cid&eacute;ieren n&euml;t an der L&euml;scht ze sinn (dir sidd "onsichtbar" fir d&eacute;i aner Benotzer).',
'texte_auteur_messagerie_1' => 'De Site erlaabt den Austausch vu Messagen a privat Forum\'en t&euml;schent den Mataarbechter. Dir k&euml;nnt d&eacute;cid&eacute;ieren n&euml;t dorun deelzehuelen.',
'texte_auteurs' => 'D\'AUTEUREN',
'texte_breves' => 'D\'Kuerzmeldungen si kuerz an einfach Texter d&eacute;i Iech erlaben Informatiounen s&eacute;ier ze publiz&eacute;ieren, eng Presse-Revue ze maachen, en Agenda ze weisen...',
'texte_choix_base_1' => 'Wielt &auml;r Datebank:',
'texte_choix_base_2' => 'Den SQL-Server huet e puer Datebanken.',
'texte_choix_base_3' => '<b>Wielt</b> hei d&eacute;i Iech vun &auml;rem Provider zougewisen gouf:',
'texte_choix_table_prefix' => 'Pr&eacute;fixe vun den Tabellen:',
'texte_commande_vider_tables_indexation' => 'Benotzt d&euml;s Prozedur fir d\'Index-Tabellen vum SPIP Sich-Motor eidel ze maachen. Domat gewant dir Disk-Plaz.',
'texte_comment_lire_tableau' => 'D\'Plaz vum Artikel am Klassement no Popularit&eacute;it steet am Rand; d\'Popularit&eacute;it vum Artikel (eng Estimatioun vun der Zuel vun de Visiten pro Dag wann &euml;t esou weidergeet) an Zuel vun de Visiten z&euml;nter Ufank stinn an der Erkl&auml;rung d&eacute;i ersch&eacute;ngt wann dier mat der Maus iwwer den Titel fuert.',
'texte_compacter_avertissement' => 'Schalt d&euml;s Optiounen n&euml;t w&auml;rend der Entw&euml;cklung vum Site an: d&eacute;i komprim&eacute;iert Elementer sinn n&euml;t einfach liesbar.',
'texte_compacter_script_css' => 'SPIP kann Javascript oder CSS Style-Sheets komprim&eacute;ieren fir als stat&euml;sch Dokumenter ze sp&auml;icheren; da ginn d\'S&auml;ite vum Site m&eacute;i s&eacute;ier gewisen.',
'texte_compresse_ou_non' => '(dee kann komprim&eacute;iert sinn oder n&euml;t)',
'texte_compresseur_page' => 'SPIP kann automat&euml;sch all S&auml;it komprim&eacute;ieren d&eacute;i ugewise g&euml;tt. D&euml;s Astellung erlaabt d\'Bandbreed ze spueren (de Site ass op enger lueser Leitung m&eacute;i s&eacute;ier), mais dat verlaangt m&eacute;i Leeschtung vum Server.',
'texte_compte_element' => '@count@ Element',
'texte_compte_elements' => '@count@ Elementer',
'texte_config_groupe_mots_cles' => 'W&euml;ll dir d&eacute;i erweidert Astellung vun de Schl&euml;sselwierder, fir z.B. unzeginn dat een een eenzegt Wuert pro Grupp kann auswielen, dat e Grupp wichteg ass...?',
'texte_conflit_edition_correction' => 'Kontroll&eacute;iert d\'&Euml;nnerscheeder t&euml;schent den zwou Versioune vum Text; dir k&euml;nnt &auml;r &Auml;nnerungen och kop&eacute;ieren an er&euml;m uf&auml;nken.',
'texte_connexion_mysql' => 'Kuckt an der Informatioun vun &auml;rem Hosting: dir musst do den Datebankserver an &auml;r pers&eacute;inlech Identifikatioun fannen.',
'texte_contenu_article' => '(Inhalt vum Artikel an e puer Wierder.)',
'texte_contenu_articles' => 'Je no Design vun &auml;rem Site k&euml;nnt dier wielen ob verschidden Elementer vun den Artikelen n&euml;t benotzt ginn.
Benotzt d\'L&euml;scht hei dr&euml;nner fir unzegin w&eacute;i eng Elementer e kann benotzen.',
'texte_crash_base' => 'Wann &auml;r Datebank ofgestiertz ass, da k&euml;nnt d&euml;r eng automatesch Reparatur prob&eacute;ieren.',
'texte_creer_rubrique' => 'Ier d&euml;r k&euml;nnt en Artikel schreiwen, musst d&euml;r eng Rubrik derb&auml;i setzen.',
'texte_date_creation_article' => 'ARTIKEL DERB&Auml;I GESAT DEN:',
'texte_date_publication_anterieure' => '&Eacute;ISCHTEN REDAKTIOUNS-DATUM:',
'texte_date_publication_anterieure_nonaffichee' => '&Eacute;ischten Redaktiouns-Datum n&euml;t weisen.',
'texte_date_publication_article' => 'PUBLIZ&Eacute;IRT DEN:',
'texte_descriptif_petition' => 'Beschreiwung vun der Petitioun',
'texte_descriptif_rapide' => 'Kuerz Beschreiwung',
'texte_documents_joints' => 'Dir k&euml;nnt Dokumenter (Fichier\'en, Biller, Multimedia, asw) bei den Artikelen an/oder de Rubriken erlaben. D&euml;s Fichier\'en k&euml;nnen dann am Artikel gelinkt oder separat ugewisen ginn.', # MODIF
'texte_documents_joints_2' => 'D&euml;s Astellung verh&euml;nnert n&euml;t Biller direkt an den Artikel derb&auml;i ze setzen.',
'texte_effacer_base' => 'D\'SPIP-Datebank l&auml;schen',
'texte_effacer_donnees_indexation' => 'Den Index l&auml;schen',
'texte_effacer_statistiques' => 'Statistik l&auml;schen',
'texte_en_cours_validation' => 'D&euml;s Artikelen a Kuerzmeldungen sinn fir d\'Publikatioun propos&eacute;iert.',
'texte_en_cours_validation_forum' => 'Gidd &auml;r Meenung am Forum deen dozou geheiert of.',
'texte_enrichir_mise_a_jour' => 'Dir k&euml;nnt de Layout verbesseren mat "typographeschen Ofkiirzungen".',
'texte_fichier_authent' => '<b>Soll SPIP d&eacute;i speziell Fichier\'en <tt>.htpasswd</tt> an <tt>.htpasswd-admin</tt> am Dossier @dossier@ maachen?</b><p>
D&euml;s Fichier\'en k&euml;nnen den Zougang vun den Redakteren an Administrateuren op verschidden Deeler vum Site kontroll&eacute;ieren (z.B. externe Statistik-Program).</p><p>
Wann dir dat n&euml;t braucht, da loosst d&euml;s Optioun op sengem Default (k&eacute;ng Fichier\'en maachen).</p>', # MODIF
'texte_informations_personnelles_1' => 'De System g&euml;t Iech elo e personnalis&eacute;ierten Zougang zum Site.',
'texte_informations_personnelles_2' => '(N.B.: wann &euml;t eng Re-Installatioun ass, a wann &auml;ren Zougang nach fonktionn&eacute;iert,',
'texte_introductif_article' => '(Aleedung vum Artikel.)',
'texte_jeu_caractere' => 'Mir roden Iech ob &auml;rem Site dat universalt Alphabet (<tt>UTF-8</tt>) ze gebrauchen: &euml;t kann d\'Texter an allen Sproochen uweisen, an huet keng Kompatibilit&eacute;its-Problemer m&eacute;i mat de moderne Browser\'en.',
'texte_jeu_caractere_2' => 'Opgepasst: D&euml;s Astellung mecht k&eacute;ng Conversioun vun den Texter d&eacute;i schons an der Datebank sinn.',
'texte_jeu_caractere_3' => '&Auml;re Site benotzt elo den Character-Set:',
'texte_jeu_caractere_4' => 'Wann dat n&euml;t der Realit&eacute;it vun &auml;ren Daten entspr&euml;cht (z.B. no enger Restauratioun vun der Datebank), oder wann dir <em>d&euml;sen Site nei uf&auml;nkt</em> an dir ob en aneren Character-Set &euml;mschalten w&euml;llt, dann gitt en elo hie un:',
'texte_jeu_caractere_conversion' => 'Dir k&euml;nnt d&eacute;cid&eacute;ieren, e fir allemol all d\'Texter vun &auml;rem Site (Artikelen, Kurzmeldungen, Forum\'en, asw) ob d\'Alphabet <tt>UTF-8</tt> ze konvert&eacute;ieren, andem dir ob <a href="@url@">d&euml;s Konversiouns-S&auml;itfir UTF-8 gidd</a>.',
'texte_lien_hypertexte' => '(Wann &auml;re Message sech op een Artikel um Internet, oder op eng S&auml;it mat m&eacute;i Informatiounen bezitt, da gitt hei s&auml;in Titel an seng URL an.)',
'texte_liens_sites_syndiques' => 'D\'Linken vun de syndiqu&eacute;ierten Siten k&euml;nnen fir d\'&eacute;ischt mol block&eacute;iert ginn; d&eacute;i Astellung ass den Default fir d&eacute;i nei syndiqu&eacute;iert Siten. Duerno kann een all Link eenzel deblock&eacute;ieren, oder Site fir Site block&eacute;ieren oder n&euml;t.',
'texte_login_ldap_1' => '(Eidel loossen fir en anonymen Zougang,  oder de kompletten Wee ugin, z.B. "&nbsp;<tt>uid=muller, ou=users, dc=domain, dc=com</tt>&nbsp;".)',
'texte_login_precaution' => 'Opgepasst! D&euml;st ass de Login mat dem dier ugemeld sidd.
Benotzt d&euml;sen Formulaire viirsichteg...',
'texte_message_edit' => 'Opgepasst: d&euml;se Message kann vun all Administrateur vum Site ge&auml;nnert ginn, an ass fir all Redakter sichtbar. Benotzt d&euml;s Annoncen n&euml;mmen fir wichteg &Eacute;v&eacute;nementer vum Site matzedeelen.',
'texte_messagerie_agenda' => 'Eng Messagerie erlaabt de Redakteren vum Site direkt am privaten Deel mateneen ze schw&auml;tzen. Sie ass en Deel vum Agenda.',
'texte_messages_publics' => '&Ouml;ffentl&euml;ch Messagen vum Artikel:',
'texte_mise_a_niveau_base_1' => 'Dir hutt en Update vun de SPIP-Fichier\'en gemaach.
Elo muss d\'Datebank vum Site ugepasst ginn.',
'texte_modifier_article' => 'Den Artikel &auml;nneren:',
'texte_moteur_recherche_active' => '<b>De Sich-Motor ass ageschalt.</b> Benotzt d&euml;s Prozedur fir eng s&eacute;ier Indexatioun (z.B. no enger Restauratioun). D&eacute;i normal &Auml;nnerungen (iwwer de SPIP-Interface) ginn automat&euml;sch nei index&eacute;iert: d&euml;s Prozedur ass n&euml;mmen an aussergew&eacute;inlechen F&auml;ll n&eacute;ideg.',
'texte_moteur_recherche_non_active' => 'De Sich-Motor ass ausgeschalt.',
'texte_mots_cles' => 'D\'Schl&euml;sselwierder erlaaben themat&euml;sch Linken t&euml;schent den Artikelen ze maachen, egal a w&eacute;i enger Rubrik se sinn. Dir k&euml;nnt esou &auml;r Navigatioun vum Site erweideren, oder d&euml;st benotzen fir de Layout vun den Artikelen an de Skeletter unzepassen.',
'texte_mots_cles_dans_forum' => 'W&euml;llt dir erlaaben dass d\'Schl&euml;sselwierder an den &ouml;ffentl&euml;che Forum\'en aschalten vun de Benotzer gewielt ginn? (Opgepasst: d&euml;s Fonktioun ass ziml&euml;ch schw&eacute;ier richteg ze benotzen.)',
'texte_multilinguisme' => 'Wann dir Artikelen a m&eacute;i Sproochen mat enger komplexer Navigatioun w&euml;llt benotzen, da k&euml;nnt dir e Menu fir d\'Sproochwiel bei den Artikelen an/oder de Rubriken aschalten, je no Organisatioun vun &auml;rem Site.',
'texte_multilinguisme_trad' => 'Dir k&euml;nnt och eng Gestioun vun de Linken t&euml;schent den Iwwersetzungen vun engem Artikel aschalten.',
'texte_non_compresse' => '<i>n&euml;t komprim&eacute;iert</i> (&auml;re Server erlaabt dat n&euml;t)',
'texte_non_fonction_referencement' => 'Dir w&euml;llt vill&auml;icht d&euml;s automatesch Fonktioun n&euml;t aschalten a selwer d\'Elementer vun &auml;rem Site uginn...',
'texte_nouveau_message' => 'Neie Message',
'texte_nouveau_mot' => 'Neit Wuert',
'texte_nouvelle_version_spip_1' => 'Dir hut eng nei Versioun vu SPIP install&eacute;iert.',
'texte_nouvelle_version_spip_2' => 'D&euml;s nei Versioun verlaangt e m&eacute;i kompletten Update w&eacute;i normalerweis. Wann dir de Webmaster vum Site sidd, l&auml;scht de Fichier @connect@ a fuert mat der Installatioun weider fir &auml;r Zougangsparameteren un d\'Datebank unzepassen.<p>(N.B.: wann dir &auml;r Parameteren vergiess hutt, kuckt am Fichier @connect@ ier d&euml;r e l&auml;scht...)</p>', # MODIF
'texte_operation_echec' => 'Gidd op d&eacute;i l&auml;scht S&auml;it zer&euml;ck, wielt eng aner Datebank oder setzt eng derb&auml;i. Kontroll&eacute;iert d\'Informatiounen vun &auml;rem Provider.',
'texte_plus_trois_car' => 'm&eacute;i w&eacute;i 3 Buchstawen',
'texte_plusieurs_articles' => 'E puer Artikelen fonnt vum "@cherche_auteur@":',
'texte_port_annuaire' => '(D\'Default-Valeur ass normalerweis d&eacute;i richteg.)',
'texte_presente_plugin' => 'D&euml;s S&auml;it weist w&eacute;i eng Plugin\'en do sinn. Dir k&euml;nnt d\'Plugin\'en aktiv&eacute;ieren andeem dier se ukr&auml;izt.',
'texte_proposer_publication' => 'Wann &auml;ren Artikel f&auml;rdeg ass,<br />k&euml;nnt d&euml;r d\'Publikatioun propos&eacute;ieren.',
'texte_proxy' => 'A best&euml;mmte F&auml;ll (Intranet, gesch&uuml;tze Netzer...) kann &euml;t n&eacute;ideg sinn iwwert en <i>HTTP-Proxy</i> ze fueren fir un d&eacute;i syndiqu&eacute;iert Siten ze kommen. An deem Fall, gidd hei seng Adress un, &euml;nner der Form @proxy_en_cours@. Normalerweis bleiwt d&euml;st Feld eidel.',
'texte_publication_articles_post_dates' => 'Wat soll SPIP mat den Artikelen maachen, wou den Publikatiouns-Datum an der Zukunft ass?',
'texte_rappel_selection_champs' => '[Vergiesst n&euml;t d&euml;st Feld richteg ze wielen.]',
'texte_recalcul_page' => 'Wann dir eng eenzeg S&auml;it nei berechne w&euml;llt, maacht dat l&eacute;iwer iwwert den &ouml;ffentl&euml;chen Deel a benotzt de Kn&auml;ppchen "Nei berechnen".',
'texte_recapitiule_liste_documents' => 'D&euml;s S&auml;it ass d\'L&euml;scht vun den Dokumenter aus de Rubriken. Fir d\'Informatiounen vun engem Dokument ze &auml;nneren, gidd mam Link op seng S&auml;it an der Rubrik.',
'texte_recuperer_base' => 'Datebank fl&eacute;cken',
'texte_reference_mais_redirige' => 'Artikel aus dem SPIP-Site, awer op eng aner URL &euml;mgeleed.',
'texte_referencement_automatique' => '<b>Automat&euml;scht Referenz&eacute;ieren vun engem Site</b><br />Dir k&euml;nnt e Site s&eacute;ier referenz&eacute;ieren an dem der hei d\'URL oder d\'Adress vun sengem Syndicatiouns-Fichier ugitt. SPIP kritt dann automatesch d\'Informatiounen (Titel, Beschreiwung...).',
'texte_referencement_automatique_verifier' => 'Kontroll&eacute;iert d\'Informatiounen d&eacute;i vun <tt>@url@</tt> koum sinn ier d&euml;r sp&auml;ichert.',
'texte_requetes_echouent' => '<b>Wa verschidden SQL-Query\'en systematesch an ouni sichtbar Ursaach fehlschlo&euml;n, ass &euml;t m&eacute;iglech dat &euml;t un der Datebank h&auml;ngt.</b><p> SQL kann seng Tabellen fl&eacute;cken wann se futti sinn. Dir k&euml;nnt hei eng Reparatur prob&eacute;ieren; wann &euml;t n&euml;t geet, kop&eacute;iert den Affichage, do sinn vill&auml;icht Hinweiser op dat wat n&euml;t fonktionn&eacute;iert...</p><p> Wann de Problem weider besteet, kontakt&eacute;iert &auml;ren Hosting.</p>', # MODIF
'texte_restaurer_base' => 'E Backup restaur&eacute;ieren',
'texte_restaurer_sauvegarde' => 'D&euml;s Fonktioun erlaabt d\'Restauratioun vun engem Backup vun der Datebank. Duerfir muss de Backup-Fichier am Dossier @dossier@ sinn.
Passt op mat d&euml;ser Prozedur: <b>d\'&Auml;nnerungen k&euml;nnen n&euml;t r&euml;ckg&auml;ngeg gemaach ginn.</b>',
'texte_sauvegarde' => 'E Backup vun der Datebank maachen',
'texte_sauvegarde_base' => 'Backup vun der Datebank maachen',
'texte_sauvegarde_compressee' => 'De Backup g&euml;t den n&euml;t komprim&eacute;ierten Fichier @fichier@.',
'texte_selection_langue_principale' => 'Hei k&euml;nnt der "d\'Haapt-Sprooch" vum Site wielen. D&euml;s Wiel forc&eacute;iert Iech n&euml;t n&euml;mmen an d&auml;r Sprooch ze schreiwen, mais:
<ul><li>s&auml;tzt den Default-Format vun den Datumen um &ouml;ffentl&euml;chen Site;</li>
<li>s&auml;tzt den typographesche Motor deen SPIP benotzen soll fir Texter ze weisen;</li>
<li>s&auml;tzt d\'Sprooch d&eacute;i an den &ouml;ffentl&euml;chen Formulairen benotzt g&euml;t;</li>
<li>s&auml;tzt d\'Default-Sprooch am privaten Deel vum Site.</li></ul>',
'texte_signification' => 'D&eacute;i kumul&eacute;iert Donn&eacute;en sinn donkel (Total vun den &Euml;nner-Rubriken), d\'Zuel vun de Visiten fir all Rubrik sinn hell.',
'texte_sous_titre' => '&Euml;nnertitel',
'texte_statistiques_visites' => '(donkel:  Sonndeg / Kurv: Evolutioun vun der Moyenne)',
'texte_statut_attente_validation' => 'waart op d\'Validatioun',
'texte_statut_publies' => 'publiz&eacute;iert',
'texte_statut_refuses' => 'refus&eacute;iert',
'texte_suppression_fichiers' => 'Benotzt d&euml;s Prozedur fir all d\'Fichier\'en aus dem Cache ze l&auml;schen. Sou k&euml;nnt dir z.B. all d\'S&auml;iten nei berechnen, wann dir  grouss &Auml;nnerungen um Layout oder der Struktur vum Site gemaach hutt.',
'texte_sur_titre' => 'Iwwertitel',
'texte_syndication' => 'Et ass m&eacute;iglech, wann de Site &euml;t erlaabt, automatesch d\'L&euml;scht vun senge Neiegkeeten ze kr&eacute;ien. Schalt duerfir d\'Syndicatioun an.
<blockquote><i>Verschidde Provideren verh&euml;nneren d&euml;s Prozedur; an deem Fall k&euml;nnt dir d\'Syndicatioun n&euml;t op &auml;rem Site benotzen.</i></blockquote>',
'texte_table_ok' => ': des Tafel ass OK.',
'texte_tables_indexation_vides' => 'Den Index vum Sich-Motor ass eidel.',
'texte_tentative_recuperation' => 'Reparatur-Versuch',
'texte_tenter_reparation' => 'Eng Reparatur vun der Datebank prob&eacute;ieren',
'texte_test_proxy' => 'Fir de Proxy ze prob&eacute;ieren, gidd hei d\'Adress vun engem Web-Site un.',
'texte_titre_02' => 'Titel:',
'texte_titre_obligatoire' => '<b>Titel</b> [Obligatoresch]',
'texte_travail_article' => '@nom_auteur_modif@ huet un d&euml;sem Artikel virun @date_diff@ Minuten geschafft',
'texte_travail_collaboratif' => 'Wann &ouml;fters e puer Redakteren un deem selwechten Artikel schaffen, kann de System d&eacute;i rezent "oppen" Artikelen weisen fir gl&auml;ichz&auml;iteg &Auml;nnerungen ze verh&euml;nneren.
D&euml;s Optioun ass par d&eacute;faut ausgeschalt fir n&euml;t andauernd Warnungen ze weisen.',
'texte_trop_resultats_auteurs' => 'Ze vill Resultater fir "@cherche_auteur@"; verbessert &auml;r Sich.',
'texte_type_urls' => 'Dir k&euml;nnt hei de Format vun der Adress vun de S&auml;ite wielen.',
'texte_type_urls_attention' => 'Opgepasst, d&euml;s Astellung fonktionn&eacute;iert n&euml;mmen wann den @htaccess@-Fichier richteg an der Root vum Site ugeluegt ass.',
'texte_unpack' => 'l&auml;scht Versioun downlueden',
'texte_utilisation_moteur_syndiques' => 'Wann d&euml;r den integr&eacute;ierte Sich-Motor benotzt, k&euml;nnt dir d\'Sichen op Siten a syndiqu&eacute;iert Artikelen op zwou Man&eacute;iere maachen.<br />- D&eacute;i einfachst ass n&euml;mmen am Titel an an der Beschreiwung vun den Artikelen ze sichen.<br />- Eng aner, besser Method, erlaabt och am Text vun den Siten ze sichen. Wann dir e Site referenz&eacute;iert, da sicht SPIP och am Text vun deem Site.',
'texte_utilisation_moteur_syndiques_2' => 'D&euml;s Method forc&eacute;iert SPIP regelm&eacute;isseg d&eacute;i referenz&eacute;iert Siten ze besichen, wat risk&eacute;iert dass &auml;ren Site e b&euml;sschen m&eacute;i lues g&euml;tt.',
'texte_vide' => 'eidel',
'texte_vider_cache' => 'De Cache l&auml;schen',
'titre_admin_effacer' => 'Maintenance',
'titre_admin_tech' => 'Maintenance',
'titre_admin_vider' => 'Maintenance',
'titre_articles_syndiques' => 'Syndiqu&eacute;iert Artikelen vun d&euml;sem Site',
'titre_breves' => 'D\'Kuerzmeldungen',
'titre_cadre_afficher_article' => 'D\'Artikelen weisen',
'titre_cadre_afficher_traductions' => 'Zoustand vun den Iwwersetzungen weisen fir d&euml;s Sproochen:',
'titre_cadre_ajouter_auteur' => 'AUTEUR DERB&Auml;I SETZEN:',
'titre_cadre_forum_administrateur' => 'Privat-Forum vun den Administrateuren',
'titre_cadre_forum_interne' => 'Internen Forum',
'titre_cadre_interieur_rubrique' => 'An der Rubrik',
'titre_cadre_numero_auteur' => 'AUTEUR NUMMER',
'titre_cadre_signature_obligatoire' => '<b>&Euml;nnerschr&euml;ft</b> [Obligatoresch]<br />',
'titre_compacter_script_css' => 'Skripter an CSS komprim&eacute;ieren',
'titre_compresser_flux_http' => 'HTTP-Flow komprim&eacute;iren',
'titre_config_contenu_notifications' => 'Meldungen',
'titre_config_contenu_prive' => 'Am privaten Deel',
'titre_config_contenu_public' => 'Um &ouml;ffentl&euml;che Site',
'titre_config_fonctions' => 'Astellen vum Site',
'titre_config_forums_prive' => 'Forumen vum privaten Deel',
'titre_config_groupe_mots_cles' => 'Astellen vun de Schl&euml;sselwierder-Gruppen',
'titre_configuration' => 'Astellen vum Site',
'titre_conflit_edition' => 'Konflikt w&auml;rend der Editioun',
'titre_connexion_ldap' => 'Optiounen: <b>&Auml;r LDAP-Verbindung</b>',
'titre_dernier_article_syndique' => 'L&auml;scht syndiqu&eacute;iert Artikelen',
'titre_documents_joints' => 'Gelinkten Dokumenter',
'titre_evolution_visite' => '&Eacute;volutioun vun de Visiten',
'titre_forum_suivi' => 'Suivi vun de Forum\'en',
'titre_gauche_mots_edit' => 'WUERT NUMMER:',
'titre_groupe_mots' => 'WUERT-GRUPP:',
'titre_langue_article' => 'SPROOCH VUM ARTIKEL',
'titre_langue_breve' => 'SPROOCH VUN DER KUERZMELDUNG',
'titre_langue_rubrique' => 'SPROOCH VUN DER RUBRIK',
'titre_langue_trad_article' => 'SPROOCH AN IWWERSETZUNGEN VUM ARTIKEL',
'titre_les_articles' => 'D\'ARTIKELEN',
'titre_messagerie_agenda' => 'Messagerie an Agenda',
'titre_mots_cles_dans_forum' => 'Schl&euml;sselwierder an de Forum\'en vum &ouml;ffentl&euml;chen Site',
'titre_mots_tous' => 'D\'Schl&euml;sselwierder',
'titre_naviguer_dans_le_site' => 'Am Site surfen...',
'titre_nouveau_groupe' => 'Neie Grupp',
'titre_nouvelle_breve' => 'Nei Kuerzmeldung',
'titre_nouvelle_rubrique' => 'Nei Rubrik',
'titre_numero_rubrique' => 'RUBRIK NUMMER:',
'titre_page_admin_effacer' => 'Maintenance: Datebank l&auml;schen',
'titre_page_articles_edit' => '&Auml;nneren: @titre@',
'titre_page_articles_page' => 'D\'Artikelen',
'titre_page_articles_tous' => 'De ganzen Site',
'titre_page_auteurs' => 'Visiteuren',
'titre_page_breves' => 'Kuerzmeldungen',
'titre_page_breves_edit' => 'Kuerzmeldung &auml;nneren: "@titre@"',
'titre_page_calendrier' => 'Kalenner @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Astellen vum Site',
'titre_page_config_fonctions' => 'Astellen vum Site',
'titre_page_configuration' => 'Astellen vum Site',
'titre_page_controle_petition' => 'Suivi vun de Petitiounen',
'titre_page_delete_all' => 'definitiv an irreversibel l&auml;schen',
'titre_page_documents_liste' => 'D\'Dokumenter aus de Rubriken',
'titre_page_forum' => 'Forum vun den Administrateuren',
'titre_page_forum_envoi' => 'Message sch&eacute;cken',
'titre_page_forum_suivi' => 'Suivi vun de Forum\'en',
'titre_page_index' => '&Auml;re privaten Deel',
'titre_page_message_edit' => 'E Message schreiwen',
'titre_page_messagerie' => '&Auml;r Messagerie',
'titre_page_mots_tous' => 'Schl&euml;sselwierder',
'titre_page_recherche' => 'Resultater vun der Sich @recherche@',
'titre_page_sites_tous' => 'D&eacute;i referenz&eacute;iert Siten',
'titre_page_statistiques' => 'Statistik pro Rubrik',
'titre_page_statistiques_messages_forum' => 'Forum-Messagen',
'titre_page_statistiques_referers' => 'Statistik (Linken d&eacute;i eran kommen)',
'titre_page_statistiques_signatures_jour' => 'Zuel vun den &Euml;nnerschr&euml;ften pro Dag',
'titre_page_statistiques_signatures_mois' => 'Zuel vun den &Euml;nnerschr&euml;fte pro Mount',
'titre_page_statistiques_visites' => 'Statistik vun de Visiten',
'titre_page_upgrade' => 'SPIP updaten',
'titre_publication_articles_post_dates' => 'Publiz&eacute;ieren vun den post-dat&eacute;ierten Artikelen',
'titre_referencement_sites' => 'Siten referenz&eacute;ieren a Syndicatioun',
'titre_referencer_site' => 'De Site referenz&eacute;ieren:',
'titre_rendez_vous' => 'RENDEZ-VOUS:',
'titre_reparation' => 'Reparatur',
'titre_site_numero' => 'SITE NUMMER:',
'titre_sites_proposes' => 'Propos&eacute;iert Siten',
'titre_sites_references_rubrique' => 'Referenz&eacute;iert Siten an d&euml;ser Rubrik',
'titre_sites_syndiques' => 'Syndiqu&eacute;iert Siten',
'titre_sites_tous' => 'D&eacute;i referenz&eacute;iert Siten',
'titre_suivi_petition' => 'Suivi vun de Petitiounen',
'titre_syndication' => 'Syndicatioun vun de Siten',
'titre_type_urls' => 'Format vun den URL-Adressen',
'tls_ldap' => 'Transport Layer Security:',
'tout_dossier_upload' => 'De ganzen Dossier @upload@',
'trad_article_inexistant' => '&Euml;t g&euml;t keen Artikel mat d&auml;r Nummer.',
'trad_article_traduction' => 'All d\'Versiounen vun d&euml;sem Artikel:',
'trad_deja_traduit' => 'Fehler: Onm&eacute;iglech d&euml;sen Artikel un d&eacute;i gefrote Nummer ze bannen.',
'trad_delier' => 'D&euml;sen Artikel n&euml;t m&eacute;i un seng Iwwersetzungen bannen',
'trad_lier' => 'D&euml;sen Artikel ass eng Iwwersetzung vum Artikel Nummer:',
'trad_new' => 'Eng nei Iwwersetzung vun d&euml;sem Artikel schreiwen',

// U
'upload_fichier_zip' => 'ZIP-Fichier',
'upload_fichier_zip_texte' => 'De Fichier deen d&euml;r install&eacute;ieren w&euml;llt ass en Zip-Fichier.',
'upload_fichier_zip_texte2' => 'D&euml;se Fichier ka sinn:',
'upload_info_mode_document' => 'D&euml;st Bild am Portfolio ofleen',
'upload_info_mode_image' => 'D&euml;st Bild aus dem Portfolio l&auml;schen',
'upload_limit' => 'D&euml;se Fichier ass ze grouss fir de Server; d&eacute;i maximal Gr&eacute;isst fir <i>eropzelueden</i> ass @max@.',
'upload_zip_conserver' => 'Archiv no der Extraktioun behalen',
'upload_zip_decompacter' => 'de-komprim&eacute;iert an all Element um Site install&eacute;iert. D\'Fichier\'en d&eacute;i dann um Site install&eacute;iert ginn sinn:',
'upload_zip_telquel' => 'esou w&eacute;i en ass, als komprim&eacute;ierten Zip-Archiv install&eacute;iert;',
'upload_zip_titrer' => 'Titel ginn bas&eacute;iert um Numm vum Fichier',
'utf8_convert_attendez' => 'Waart e b&euml;schen a lued dann d&euml;s S&auml;it nei.',
'utf8_convert_avertissement' => 'Dir w&auml;rt elo den Inhalt vun &auml;rer Datebank (Artikelen, Kurzmeldungen, asw) vum Character-Set <strong>@orig@</strong> ob <strong>@charset@</strong> &auml;nneren.',
'utf8_convert_backup' => 'Vergiesst n&euml;t virdrun e kompletten Backup vun &auml;rem Site ze maachen. Dir musst och kontroll&eacute;ieren ob &auml;r Skeletter a Sproch-Fichier\'en @charset@ kompatibel sinn.',
'utf8_convert_erreur_deja' => '&Auml;ren Site ass schon ob @charset@, kee W&auml;rt ze konvert&eacute;ieren...',
'utf8_convert_erreur_orig' => 'Fehler: den Character-Set @charset@ g&euml;tt n&euml;t &euml;nnerst&euml;tzt.',
'utf8_convert_termine' => 'Et ass f&auml;rdeg!',
'utf8_convert_timeout' => '<strong>Wichteg:</strong> wann &auml;ren Server en <em>Timeout</em> m&euml;cht, lued d&euml;s S&auml;it nei bis se "F&auml;rdeg" weist.',
'utf8_convert_verifier' => 'Dir musst elo de Cache l&auml;schen a kontroll&eacute;ieren ob alles ob dem &ouml;ffentl&euml;chen Site richteg ass. Fir de Fall vu grousse Problemer l&auml;it am Dossier @rep@ e Backup am Format SQL.',
'utf8_convertir_votre_site' => '&Auml;ren Site ob UTF-8 konvert&eacute;ieren',

// V
'version' => 'Versioun:',
'version_deplace_rubrique' => 'Verschoben vun <b>"@from@"</b> op <b>"@to@"</b>.',
'version_initiale' => 'Original-Versioun'
);

?>
